from typing import List, Optional, Union

import pytest

from kittycad.api.ai import create_image_to_3d, create_text_to_3d
from kittycad.api.api_calls import (
    get_api_call,
    get_api_call_for_user,
    get_api_call_metrics,
    get_async_operation,
    list_api_calls,
    list_api_calls_for_user,
    list_async_operations,
    user_list_api_calls,
)
from kittycad.api.api_tokens import (
    create_api_token_for_user,
    delete_api_token_for_user,
    get_api_token_for_user,
    list_api_tokens_for_user,
)
from kittycad.api.apps import (
    apps_github_callback,
    apps_github_consent,
    apps_github_webhook,
)
from kittycad.api.constant import get_physics_constant
from kittycad.api.executor import create_executor_term, create_file_execution
from kittycad.api.file import (
    create_file_center_of_mass,
    create_file_conversion,
    create_file_conversion_with_base64_helper,
    create_file_density,
    create_file_mass,
    create_file_surface_area,
    create_file_volume,
)
from kittycad.api.hidden import auth_email, auth_email_callback, logout
from kittycad.api.meta import (
    get_ai_plugin_manifest,
    get_metadata,
    get_openai_schema,
    get_schema,
    ping,
)
from kittycad.api.modeling import cmd, cmd_batch, modeling_commands_ws
from kittycad.api.payments import (
    create_payment_information_for_user,
    create_payment_intent_for_user,
    delete_payment_information_for_user,
    delete_payment_method_for_user,
    get_payment_balance_for_user,
    get_payment_information_for_user,
    list_invoices_for_user,
    list_payment_methods_for_user,
    update_payment_information_for_user,
    validate_customer_tax_information_for_user,
)
from kittycad.api.unit import (
    get_angle_unit_conversion,
    get_area_unit_conversion,
    get_current_unit_conversion,
    get_energy_unit_conversion,
    get_force_unit_conversion,
    get_frequency_unit_conversion,
    get_length_unit_conversion,
    get_mass_unit_conversion,
    get_power_unit_conversion,
    get_pressure_unit_conversion,
    get_temperature_unit_conversion,
    get_torque_unit_conversion,
    get_volume_unit_conversion,
)
from kittycad.api.users import (
    delete_user_self,
    get_session_for_user,
    get_user,
    get_user_extended,
    get_user_front_hash_self,
    get_user_onboarding_self,
    get_user_self,
    get_user_self_extended,
    list_users,
    list_users_extended,
    update_user_self,
)
from kittycad.client import ClientFromEnv
from kittycad.models import (
    AiPluginManifest,
    ApiCallQueryGroup,
    ApiCallWithPrice,
    ApiCallWithPriceResultsPage,
    ApiToken,
    ApiTokenResultsPage,
    AppClientInfo,
    AsyncApiCallResultsPage,
    CodeOutput,
    Customer,
    CustomerBalance,
    Error,
    ExtendedUser,
    ExtendedUserResultsPage,
    FileCenterOfMass,
    FileConversion,
    FileDensity,
    FileMass,
    FileSurfaceArea,
    FileVolume,
    Invoice,
    Mesh,
    Metadata,
    ModelingOutcomes,
    Onboarding,
    PaymentIntent,
    PaymentMethod,
    PhysicsConstant,
    Pong,
    Session,
    UnitAngleConversion,
    UnitAreaConversion,
    UnitCurrentConversion,
    UnitEnergyConversion,
    UnitForceConversion,
    UnitFrequencyConversion,
    UnitLengthConversion,
    UnitMassConversion,
    UnitPowerConversion,
    UnitPressureConversion,
    UnitTemperatureConversion,
    UnitTorqueConversion,
    UnitVolumeConversion,
    User,
    UserResultsPage,
    VerificationToken,
)
from kittycad.models.api_call_query_group_by import ApiCallQueryGroupBy
from kittycad.models.api_call_status import ApiCallStatus
from kittycad.models.billing_info import BillingInfo
from kittycad.models.code_language import CodeLanguage
from kittycad.models.created_at_sort_mode import CreatedAtSortMode
from kittycad.models.email_authentication_form import EmailAuthenticationForm
from kittycad.models.file_export_format import FileExportFormat
from kittycad.models.file_import_format import FileImportFormat
from kittycad.models.image_type import ImageType
from kittycad.models.modeling_cmd import ModelingCmd
from kittycad.models.modeling_cmd_id import ModelingCmdId
from kittycad.models.modeling_cmd_req import ModelingCmdReq
from kittycad.models.modeling_cmd_req_batch import ModelingCmdReqBatch
from kittycad.models.physics_constant_name import PhysicsConstantName
from kittycad.models.unit_angle import UnitAngle
from kittycad.models.unit_area import UnitArea
from kittycad.models.unit_current import UnitCurrent
from kittycad.models.unit_energy import UnitEnergy
from kittycad.models.unit_force import UnitForce
from kittycad.models.unit_frequency import UnitFrequency
from kittycad.models.unit_length import UnitLength
from kittycad.models.unit_mass import UnitMass
from kittycad.models.unit_power import UnitPower
from kittycad.models.unit_pressure import UnitPressure
from kittycad.models.unit_temperature import UnitTemperature
from kittycad.models.unit_torque import UnitTorque
from kittycad.models.unit_volume import UnitVolume
from kittycad.models.update_user import UpdateUser
from kittycad.types import Response


@pytest.mark.skip
def test_get_schema():
    # Create our client.
    client = ClientFromEnv()

    get_schema.sync(
        client=client,
    )

    # OR if you need more info (e.g. status_code)
    get_schema.sync_detailed(
        client=client,
    )


# OR run async
@pytest.mark.asyncio
@pytest.mark.skip
async def test_get_schema_async():
    # Create our client.
    client = ClientFromEnv()

    await get_schema.asyncio(
        client=client,
    )

    # OR run async with more info
    await get_schema.asyncio_detailed(
        client=client,
    )


@pytest.mark.skip
def test_get_ai_plugin_manifest():
    # Create our client.
    client = ClientFromEnv()

    result: Optional[Union[AiPluginManifest, Error]] = get_ai_plugin_manifest.sync(
        client=client,
    )

    if isinstance(result, Error) or result is None:
        print(result)
        raise Exception("Error in response")

    body: AiPluginManifest = result
    print(body)

    # OR if you need more info (e.g. status_code)
    response: Response[
        Optional[Union[AiPluginManifest, Error]]
    ] = get_ai_plugin_manifest.sync_detailed(
        client=client,
    )


# OR run async
@pytest.mark.asyncio
@pytest.mark.skip
async def test_get_ai_plugin_manifest_async():
    # Create our client.
    client = ClientFromEnv()

    result: Optional[
        Union[AiPluginManifest, Error]
    ] = await get_ai_plugin_manifest.asyncio(
        client=client,
    )

    # OR run async with more info
    response: Response[
        Optional[Union[AiPluginManifest, Error]]
    ] = await get_ai_plugin_manifest.asyncio_detailed(
        client=client,
    )


@pytest.mark.skip
def test_get_metadata():
    # Create our client.
    client = ClientFromEnv()

    result: Optional[Union[Metadata, Error]] = get_metadata.sync(
        client=client,
    )

    if isinstance(result, Error) or result is None:
        print(result)
        raise Exception("Error in response")

    body: Metadata = result
    print(body)

    # OR if you need more info (e.g. status_code)
    response: Response[Optional[Union[Metadata, Error]]] = get_metadata.sync_detailed(
        client=client,
    )


# OR run async
@pytest.mark.asyncio
@pytest.mark.skip
async def test_get_metadata_async():
    # Create our client.
    client = ClientFromEnv()

    result: Optional[Union[Metadata, Error]] = await get_metadata.asyncio(
        client=client,
    )

    # OR run async with more info
    response: Response[
        Optional[Union[Metadata, Error]]
    ] = await get_metadata.asyncio_detailed(
        client=client,
    )


@pytest.mark.skip
def test_create_image_to_3d():
    # Create our client.
    client = ClientFromEnv()

    result: Optional[Union[Mesh, Error]] = create_image_to_3d.sync(
        client=client,
        input_format=ImageType.PNG,
        output_format=FileExportFormat.DAE,
        body=bytes("some bytes", "utf-8"),
    )

    if isinstance(result, Error) or result is None:
        print(result)
        raise Exception("Error in response")

    body: Mesh = result
    print(body)

    # OR if you need more info (e.g. status_code)
    response: Response[Optional[Union[Mesh, Error]]] = create_image_to_3d.sync_detailed(
        client=client,
        input_format=ImageType.PNG,
        output_format=FileExportFormat.DAE,
        body=bytes("some bytes", "utf-8"),
    )


# OR run async
@pytest.mark.asyncio
@pytest.mark.skip
async def test_create_image_to_3d_async():
    # Create our client.
    client = ClientFromEnv()

    result: Optional[Union[Mesh, Error]] = await create_image_to_3d.asyncio(
        client=client,
        input_format=ImageType.PNG,
        output_format=FileExportFormat.DAE,
        body=bytes("some bytes", "utf-8"),
    )

    # OR run async with more info
    response: Response[
        Optional[Union[Mesh, Error]]
    ] = await create_image_to_3d.asyncio_detailed(
        client=client,
        input_format=ImageType.PNG,
        output_format=FileExportFormat.DAE,
        body=bytes("some bytes", "utf-8"),
    )


@pytest.mark.skip
def test_create_text_to_3d():
    # Create our client.
    client = ClientFromEnv()

    result: Optional[Union[Mesh, Error]] = create_text_to_3d.sync(
        client=client,
        output_format=FileExportFormat.DAE,
        prompt="<string>",
    )

    if isinstance(result, Error) or result is None:
        print(result)
        raise Exception("Error in response")

    body: Mesh = result
    print(body)

    # OR if you need more info (e.g. status_code)
    response: Response[Optional[Union[Mesh, Error]]] = create_text_to_3d.sync_detailed(
        client=client,
        output_format=FileExportFormat.DAE,
        prompt="<string>",
    )


# OR run async
@pytest.mark.asyncio
@pytest.mark.skip
async def test_create_text_to_3d_async():
    # Create our client.
    client = ClientFromEnv()

    result: Optional[Union[Mesh, Error]] = await create_text_to_3d.asyncio(
        client=client,
        output_format=FileExportFormat.DAE,
        prompt="<string>",
    )

    # OR run async with more info
    response: Response[
        Optional[Union[Mesh, Error]]
    ] = await create_text_to_3d.asyncio_detailed(
        client=client,
        output_format=FileExportFormat.DAE,
        prompt="<string>",
    )


@pytest.mark.skip
def test_get_api_call_metrics():
    # Create our client.
    client = ClientFromEnv()

    result: Optional[Union[List[ApiCallQueryGroup], Error]] = get_api_call_metrics.sync(
        client=client,
        group_by=ApiCallQueryGroupBy.EMAIL,
    )

    if isinstance(result, Error) or result is None:
        print(result)
        raise Exception("Error in response")

    body: List[ApiCallQueryGroup] = result
    print(body)

    # OR if you need more info (e.g. status_code)
    response: Response[
        Optional[Union[List[ApiCallQueryGroup], Error]]
    ] = get_api_call_metrics.sync_detailed(
        client=client,
        group_by=ApiCallQueryGroupBy.EMAIL,
    )


# OR run async
@pytest.mark.asyncio
@pytest.mark.skip
async def test_get_api_call_metrics_async():
    # Create our client.
    client = ClientFromEnv()

    result: Optional[
        Union[List[ApiCallQueryGroup], Error]
    ] = await get_api_call_metrics.asyncio(
        client=client,
        group_by=ApiCallQueryGroupBy.EMAIL,
    )

    # OR run async with more info
    response: Response[
        Optional[Union[List[ApiCallQueryGroup], Error]]
    ] = await get_api_call_metrics.asyncio_detailed(
        client=client,
        group_by=ApiCallQueryGroupBy.EMAIL,
    )


@pytest.mark.skip
def test_list_api_calls():
    # Create our client.
    client = ClientFromEnv()

    result: Optional[Union[ApiCallWithPriceResultsPage, Error]] = list_api_calls.sync(
        client=client,
        sort_by=CreatedAtSortMode.CREATED_AT_ASCENDING,
        limit=None,  # Optional[int]
        page_token=None,  # Optional[str]
    )

    if isinstance(result, Error) or result is None:
        print(result)
        raise Exception("Error in response")

    body: ApiCallWithPriceResultsPage = result
    print(body)

    # OR if you need more info (e.g. status_code)
    response: Response[
        Optional[Union[ApiCallWithPriceResultsPage, Error]]
    ] = list_api_calls.sync_detailed(
        client=client,
        sort_by=CreatedAtSortMode.CREATED_AT_ASCENDING,
        limit=None,  # Optional[int]
        page_token=None,  # Optional[str]
    )


# OR run async
@pytest.mark.asyncio
@pytest.mark.skip
async def test_list_api_calls_async():
    # Create our client.
    client = ClientFromEnv()

    result: Optional[
        Union[ApiCallWithPriceResultsPage, Error]
    ] = await list_api_calls.asyncio(
        client=client,
        sort_by=CreatedAtSortMode.CREATED_AT_ASCENDING,
        limit=None,  # Optional[int]
        page_token=None,  # Optional[str]
    )

    # OR run async with more info
    response: Response[
        Optional[Union[ApiCallWithPriceResultsPage, Error]]
    ] = await list_api_calls.asyncio_detailed(
        client=client,
        sort_by=CreatedAtSortMode.CREATED_AT_ASCENDING,
        limit=None,  # Optional[int]
        page_token=None,  # Optional[str]
    )


@pytest.mark.skip
def test_get_api_call():
    # Create our client.
    client = ClientFromEnv()

    result: Optional[Union[ApiCallWithPrice, Error]] = get_api_call.sync(
        client=client,
        id="<string>",
    )

    if isinstance(result, Error) or result is None:
        print(result)
        raise Exception("Error in response")

    body: ApiCallWithPrice = result
    print(body)

    # OR if you need more info (e.g. status_code)
    response: Response[
        Optional[Union[ApiCallWithPrice, Error]]
    ] = get_api_call.sync_detailed(
        client=client,
        id="<string>",
    )


# OR run async
@pytest.mark.asyncio
@pytest.mark.skip
async def test_get_api_call_async():
    # Create our client.
    client = ClientFromEnv()

    result: Optional[Union[ApiCallWithPrice, Error]] = await get_api_call.asyncio(
        client=client,
        id="<string>",
    )

    # OR run async with more info
    response: Response[
        Optional[Union[ApiCallWithPrice, Error]]
    ] = await get_api_call.asyncio_detailed(
        client=client,
        id="<string>",
    )


@pytest.mark.skip
def test_apps_github_callback():
    # Create our client.
    client = ClientFromEnv()

    result: Optional[Error] = apps_github_callback.sync(
        client=client,
    )

    if isinstance(result, Error) or result is None:
        print(result)
        raise Exception("Error in response")

    body: Error = result
    print(body)

    # OR if you need more info (e.g. status_code)
    response: Response[Optional[Error]] = apps_github_callback.sync_detailed(
        client=client,
    )


# OR run async
@pytest.mark.asyncio
@pytest.mark.skip
async def test_apps_github_callback_async():
    # Create our client.
    client = ClientFromEnv()

    result: Optional[Error] = await apps_github_callback.asyncio(
        client=client,
    )

    # OR run async with more info
    response: Response[Optional[Error]] = await apps_github_callback.asyncio_detailed(
        client=client,
    )


@pytest.mark.skip
def test_apps_github_consent():
    # Create our client.
    client = ClientFromEnv()

    result: Optional[Union[AppClientInfo, Error]] = apps_github_consent.sync(
        client=client,
    )

    if isinstance(result, Error) or result is None:
        print(result)
        raise Exception("Error in response")

    body: AppClientInfo = result
    print(body)

    # OR if you need more info (e.g. status_code)
    response: Response[
        Optional[Union[AppClientInfo, Error]]
    ] = apps_github_consent.sync_detailed(
        client=client,
    )


# OR run async
@pytest.mark.asyncio
@pytest.mark.skip
async def test_apps_github_consent_async():
    # Create our client.
    client = ClientFromEnv()

    result: Optional[Union[AppClientInfo, Error]] = await apps_github_consent.asyncio(
        client=client,
    )

    # OR run async with more info
    response: Response[
        Optional[Union[AppClientInfo, Error]]
    ] = await apps_github_consent.asyncio_detailed(
        client=client,
    )


@pytest.mark.skip
def test_apps_github_webhook():
    # Create our client.
    client = ClientFromEnv()

    result: Optional[Error] = apps_github_webhook.sync(
        client=client,
        body=bytes("some bytes", "utf-8"),
    )

    if isinstance(result, Error) or result is None:
        print(result)
        raise Exception("Error in response")

    body: Error = result
    print(body)

    # OR if you need more info (e.g. status_code)
    response: Response[Optional[Error]] = apps_github_webhook.sync_detailed(
        client=client,
        body=bytes("some bytes", "utf-8"),
    )


# OR run async
@pytest.mark.asyncio
@pytest.mark.skip
async def test_apps_github_webhook_async():
    # Create our client.
    client = ClientFromEnv()

    result: Optional[Error] = await apps_github_webhook.asyncio(
        client=client,
        body=bytes("some bytes", "utf-8"),
    )

    # OR run async with more info
    response: Response[Optional[Error]] = await apps_github_webhook.asyncio_detailed(
        client=client,
        body=bytes("some bytes", "utf-8"),
    )


@pytest.mark.skip
def test_list_async_operations():
    # Create our client.
    client = ClientFromEnv()

    result: Optional[
        Union[AsyncApiCallResultsPage, Error]
    ] = list_async_operations.sync(
        client=client,
        sort_by=CreatedAtSortMode.CREATED_AT_ASCENDING,
        status=ApiCallStatus.QUEUED,
        limit=None,  # Optional[int]
        page_token=None,  # Optional[str]
    )

    if isinstance(result, Error) or result is None:
        print(result)
        raise Exception("Error in response")

    body: AsyncApiCallResultsPage = result
    print(body)

    # OR if you need more info (e.g. status_code)
    response: Response[
        Optional[Union[AsyncApiCallResultsPage, Error]]
    ] = list_async_operations.sync_detailed(
        client=client,
        sort_by=CreatedAtSortMode.CREATED_AT_ASCENDING,
        status=ApiCallStatus.QUEUED,
        limit=None,  # Optional[int]
        page_token=None,  # Optional[str]
    )


# OR run async
@pytest.mark.asyncio
@pytest.mark.skip
async def test_list_async_operations_async():
    # Create our client.
    client = ClientFromEnv()

    result: Optional[
        Union[AsyncApiCallResultsPage, Error]
    ] = await list_async_operations.asyncio(
        client=client,
        sort_by=CreatedAtSortMode.CREATED_AT_ASCENDING,
        status=ApiCallStatus.QUEUED,
        limit=None,  # Optional[int]
        page_token=None,  # Optional[str]
    )

    # OR run async with more info
    response: Response[
        Optional[Union[AsyncApiCallResultsPage, Error]]
    ] = await list_async_operations.asyncio_detailed(
        client=client,
        sort_by=CreatedAtSortMode.CREATED_AT_ASCENDING,
        status=ApiCallStatus.QUEUED,
        limit=None,  # Optional[int]
        page_token=None,  # Optional[str]
    )


@pytest.mark.skip
def test_get_async_operation():
    # Create our client.
    client = ClientFromEnv()

    result: Optional[
        Union[
            FileConversion,
            FileCenterOfMass,
            FileMass,
            FileVolume,
            FileDensity,
            FileSurfaceArea,
            Error,
        ]
    ] = get_async_operation.sync(
        client=client,
        id="<string>",
    )

    if isinstance(result, Error) or result is None:
        print(result)
        raise Exception("Error in response")

    body: Union[
        FileConversion,
        FileCenterOfMass,
        FileMass,
        FileVolume,
        FileDensity,
        FileSurfaceArea,
    ] = result
    print(body)

    # OR if you need more info (e.g. status_code)
    response: Response[
        Optional[
            Union[
                FileConversion,
                FileCenterOfMass,
                FileMass,
                FileVolume,
                FileDensity,
                FileSurfaceArea,
                Error,
            ]
        ]
    ] = get_async_operation.sync_detailed(
        client=client,
        id="<string>",
    )


# OR run async
@pytest.mark.asyncio
@pytest.mark.skip
async def test_get_async_operation_async():
    # Create our client.
    client = ClientFromEnv()

    result: Optional[
        Union[
            FileConversion,
            FileCenterOfMass,
            FileMass,
            FileVolume,
            FileDensity,
            FileSurfaceArea,
            Error,
        ]
    ] = await get_async_operation.asyncio(
        client=client,
        id="<string>",
    )

    # OR run async with more info
    response: Response[
        Optional[
            Union[
                FileConversion,
                FileCenterOfMass,
                FileMass,
                FileVolume,
                FileDensity,
                FileSurfaceArea,
                Error,
            ]
        ]
    ] = await get_async_operation.asyncio_detailed(
        client=client,
        id="<string>",
    )


@pytest.mark.skip
def test_auth_email():
    # Create our client.
    client = ClientFromEnv()

    result: Optional[Union[VerificationToken, Error]] = auth_email.sync(
        client=client,
        body=EmailAuthenticationForm(
            email="<string>",
        ),
    )

    if isinstance(result, Error) or result is None:
        print(result)
        raise Exception("Error in response")

    body: VerificationToken = result
    print(body)

    # OR if you need more info (e.g. status_code)
    response: Response[
        Optional[Union[VerificationToken, Error]]
    ] = auth_email.sync_detailed(
        client=client,
        body=EmailAuthenticationForm(
            email="<string>",
        ),
    )


# OR run async
@pytest.mark.asyncio
@pytest.mark.skip
async def test_auth_email_async():
    # Create our client.
    client = ClientFromEnv()

    result: Optional[Union[VerificationToken, Error]] = await auth_email.asyncio(
        client=client,
        body=EmailAuthenticationForm(
            email="<string>",
        ),
    )

    # OR run async with more info
    response: Response[
        Optional[Union[VerificationToken, Error]]
    ] = await auth_email.asyncio_detailed(
        client=client,
        body=EmailAuthenticationForm(
            email="<string>",
        ),
    )


@pytest.mark.skip
def test_auth_email_callback():
    # Create our client.
    client = ClientFromEnv()

    result: Optional[Error] = auth_email_callback.sync(
        client=client,
        email="<string>",
        token="<string>",
        callback_url=None,  # Optional[str]
    )

    if isinstance(result, Error) or result is None:
        print(result)
        raise Exception("Error in response")

    body: Error = result
    print(body)

    # OR if you need more info (e.g. status_code)
    response: Response[Optional[Error]] = auth_email_callback.sync_detailed(
        client=client,
        email="<string>",
        token="<string>",
        callback_url=None,  # Optional[str]
    )


# OR run async
@pytest.mark.asyncio
@pytest.mark.skip
async def test_auth_email_callback_async():
    # Create our client.
    client = ClientFromEnv()

    result: Optional[Error] = await auth_email_callback.asyncio(
        client=client,
        email="<string>",
        token="<string>",
        callback_url=None,  # Optional[str]
    )

    # OR run async with more info
    response: Response[Optional[Error]] = await auth_email_callback.asyncio_detailed(
        client=client,
        email="<string>",
        token="<string>",
        callback_url=None,  # Optional[str]
    )


@pytest.mark.skip
def test_get_physics_constant():
    # Create our client.
    client = ClientFromEnv()

    result: Optional[Union[PhysicsConstant, Error]] = get_physics_constant.sync(
        client=client,
        constant=PhysicsConstantName.PI,
    )

    if isinstance(result, Error) or result is None:
        print(result)
        raise Exception("Error in response")

    body: PhysicsConstant = result
    print(body)

    # OR if you need more info (e.g. status_code)
    response: Response[
        Optional[Union[PhysicsConstant, Error]]
    ] = get_physics_constant.sync_detailed(
        client=client,
        constant=PhysicsConstantName.PI,
    )


# OR run async
@pytest.mark.asyncio
@pytest.mark.skip
async def test_get_physics_constant_async():
    # Create our client.
    client = ClientFromEnv()

    result: Optional[
        Union[PhysicsConstant, Error]
    ] = await get_physics_constant.asyncio(
        client=client,
        constant=PhysicsConstantName.PI,
    )

    # OR run async with more info
    response: Response[
        Optional[Union[PhysicsConstant, Error]]
    ] = await get_physics_constant.asyncio_detailed(
        client=client,
        constant=PhysicsConstantName.PI,
    )


@pytest.mark.skip
def test_create_file_center_of_mass():
    # Create our client.
    client = ClientFromEnv()

    result: Optional[Union[FileCenterOfMass, Error]] = create_file_center_of_mass.sync(
        client=client,
        src_format=FileImportFormat.DAE,
        body=bytes("some bytes", "utf-8"),
    )

    if isinstance(result, Error) or result is None:
        print(result)
        raise Exception("Error in response")

    body: FileCenterOfMass = result
    print(body)

    # OR if you need more info (e.g. status_code)
    response: Response[
        Optional[Union[FileCenterOfMass, Error]]
    ] = create_file_center_of_mass.sync_detailed(
        client=client,
        src_format=FileImportFormat.DAE,
        body=bytes("some bytes", "utf-8"),
    )


# OR run async
@pytest.mark.asyncio
@pytest.mark.skip
async def test_create_file_center_of_mass_async():
    # Create our client.
    client = ClientFromEnv()

    result: Optional[
        Union[FileCenterOfMass, Error]
    ] = await create_file_center_of_mass.asyncio(
        client=client,
        src_format=FileImportFormat.DAE,
        body=bytes("some bytes", "utf-8"),
    )

    # OR run async with more info
    response: Response[
        Optional[Union[FileCenterOfMass, Error]]
    ] = await create_file_center_of_mass.asyncio_detailed(
        client=client,
        src_format=FileImportFormat.DAE,
        body=bytes("some bytes", "utf-8"),
    )


@pytest.mark.skip
def test_create_file_conversion_with_base64_helper():
    # Create our client.
    client = ClientFromEnv()

    result: Optional[
        Union[FileConversion, Error]
    ] = create_file_conversion_with_base64_helper.sync(
        client=client,
        output_format=FileExportFormat.DAE,
        src_format=FileImportFormat.DAE,
        body=bytes("some bytes", "utf-8"),
    )

    if isinstance(result, Error) or result is None:
        print(result)
        raise Exception("Error in response")

    body: FileConversion = result
    print(body)

    # OR if you need more info (e.g. status_code)
    response: Response[
        Optional[Union[FileConversion, Error]]
    ] = create_file_conversion.sync_detailed(
        client=client,
        output_format=FileExportFormat.DAE,
        src_format=FileImportFormat.DAE,
        body=bytes("some bytes", "utf-8"),
    )


# OR run async
@pytest.mark.asyncio
@pytest.mark.skip
async def test_create_file_conversion_with_base64_helper_async():
    # Create our client.
    client = ClientFromEnv()

    result: Optional[
        Union[FileConversion, Error]
    ] = await create_file_conversion_with_base64_helper.asyncio(
        client=client,
        output_format=FileExportFormat.DAE,
        src_format=FileImportFormat.DAE,
        body=bytes("some bytes", "utf-8"),
    )

    # OR run async with more info
    response: Response[
        Optional[Union[FileConversion, Error]]
    ] = await create_file_conversion.asyncio_detailed(
        client=client,
        output_format=FileExportFormat.DAE,
        src_format=FileImportFormat.DAE,
        body=bytes("some bytes", "utf-8"),
    )


@pytest.mark.skip
def test_create_file_density():
    # Create our client.
    client = ClientFromEnv()

    result: Optional[Union[FileDensity, Error]] = create_file_density.sync(
        client=client,
        material_mass=3.14,
        src_format=FileImportFormat.DAE,
        body=bytes("some bytes", "utf-8"),
    )

    if isinstance(result, Error) or result is None:
        print(result)
        raise Exception("Error in response")

    body: FileDensity = result
    print(body)

    # OR if you need more info (e.g. status_code)
    response: Response[
        Optional[Union[FileDensity, Error]]
    ] = create_file_density.sync_detailed(
        client=client,
        material_mass=3.14,
        src_format=FileImportFormat.DAE,
        body=bytes("some bytes", "utf-8"),
    )


# OR run async
@pytest.mark.asyncio
@pytest.mark.skip
async def test_create_file_density_async():
    # Create our client.
    client = ClientFromEnv()

    result: Optional[Union[FileDensity, Error]] = await create_file_density.asyncio(
        client=client,
        material_mass=3.14,
        src_format=FileImportFormat.DAE,
        body=bytes("some bytes", "utf-8"),
    )

    # OR run async with more info
    response: Response[
        Optional[Union[FileDensity, Error]]
    ] = await create_file_density.asyncio_detailed(
        client=client,
        material_mass=3.14,
        src_format=FileImportFormat.DAE,
        body=bytes("some bytes", "utf-8"),
    )


@pytest.mark.skip
def test_create_file_execution():
    # Create our client.
    client = ClientFromEnv()

    result: Optional[Union[CodeOutput, Error]] = create_file_execution.sync(
        client=client,
        lang=CodeLanguage.GO,
        output=None,  # Optional[str]
        body=bytes("some bytes", "utf-8"),
    )

    if isinstance(result, Error) or result is None:
        print(result)
        raise Exception("Error in response")

    body: CodeOutput = result
    print(body)

    # OR if you need more info (e.g. status_code)
    response: Response[
        Optional[Union[CodeOutput, Error]]
    ] = create_file_execution.sync_detailed(
        client=client,
        lang=CodeLanguage.GO,
        output=None,  # Optional[str]
        body=bytes("some bytes", "utf-8"),
    )


# OR run async
@pytest.mark.asyncio
@pytest.mark.skip
async def test_create_file_execution_async():
    # Create our client.
    client = ClientFromEnv()

    result: Optional[Union[CodeOutput, Error]] = await create_file_execution.asyncio(
        client=client,
        lang=CodeLanguage.GO,
        output=None,  # Optional[str]
        body=bytes("some bytes", "utf-8"),
    )

    # OR run async with more info
    response: Response[
        Optional[Union[CodeOutput, Error]]
    ] = await create_file_execution.asyncio_detailed(
        client=client,
        lang=CodeLanguage.GO,
        output=None,  # Optional[str]
        body=bytes("some bytes", "utf-8"),
    )


@pytest.mark.skip
def test_create_file_mass():
    # Create our client.
    client = ClientFromEnv()

    result: Optional[Union[FileMass, Error]] = create_file_mass.sync(
        client=client,
        material_density=3.14,
        src_format=FileImportFormat.DAE,
        body=bytes("some bytes", "utf-8"),
    )

    if isinstance(result, Error) or result is None:
        print(result)
        raise Exception("Error in response")

    body: FileMass = result
    print(body)

    # OR if you need more info (e.g. status_code)
    response: Response[
        Optional[Union[FileMass, Error]]
    ] = create_file_mass.sync_detailed(
        client=client,
        material_density=3.14,
        src_format=FileImportFormat.DAE,
        body=bytes("some bytes", "utf-8"),
    )


# OR run async
@pytest.mark.asyncio
@pytest.mark.skip
async def test_create_file_mass_async():
    # Create our client.
    client = ClientFromEnv()

    result: Optional[Union[FileMass, Error]] = await create_file_mass.asyncio(
        client=client,
        material_density=3.14,
        src_format=FileImportFormat.DAE,
        body=bytes("some bytes", "utf-8"),
    )

    # OR run async with more info
    response: Response[
        Optional[Union[FileMass, Error]]
    ] = await create_file_mass.asyncio_detailed(
        client=client,
        material_density=3.14,
        src_format=FileImportFormat.DAE,
        body=bytes("some bytes", "utf-8"),
    )


@pytest.mark.skip
def test_create_file_surface_area():
    # Create our client.
    client = ClientFromEnv()

    result: Optional[Union[FileSurfaceArea, Error]] = create_file_surface_area.sync(
        client=client,
        src_format=FileImportFormat.DAE,
        body=bytes("some bytes", "utf-8"),
    )

    if isinstance(result, Error) or result is None:
        print(result)
        raise Exception("Error in response")

    body: FileSurfaceArea = result
    print(body)

    # OR if you need more info (e.g. status_code)
    response: Response[
        Optional[Union[FileSurfaceArea, Error]]
    ] = create_file_surface_area.sync_detailed(
        client=client,
        src_format=FileImportFormat.DAE,
        body=bytes("some bytes", "utf-8"),
    )


# OR run async
@pytest.mark.asyncio
@pytest.mark.skip
async def test_create_file_surface_area_async():
    # Create our client.
    client = ClientFromEnv()

    result: Optional[
        Union[FileSurfaceArea, Error]
    ] = await create_file_surface_area.asyncio(
        client=client,
        src_format=FileImportFormat.DAE,
        body=bytes("some bytes", "utf-8"),
    )

    # OR run async with more info
    response: Response[
        Optional[Union[FileSurfaceArea, Error]]
    ] = await create_file_surface_area.asyncio_detailed(
        client=client,
        src_format=FileImportFormat.DAE,
        body=bytes("some bytes", "utf-8"),
    )


@pytest.mark.skip
def test_create_file_volume():
    # Create our client.
    client = ClientFromEnv()

    result: Optional[Union[FileVolume, Error]] = create_file_volume.sync(
        client=client,
        src_format=FileImportFormat.DAE,
        body=bytes("some bytes", "utf-8"),
    )

    if isinstance(result, Error) or result is None:
        print(result)
        raise Exception("Error in response")

    body: FileVolume = result
    print(body)

    # OR if you need more info (e.g. status_code)
    response: Response[
        Optional[Union[FileVolume, Error]]
    ] = create_file_volume.sync_detailed(
        client=client,
        src_format=FileImportFormat.DAE,
        body=bytes("some bytes", "utf-8"),
    )


# OR run async
@pytest.mark.asyncio
@pytest.mark.skip
async def test_create_file_volume_async():
    # Create our client.
    client = ClientFromEnv()

    result: Optional[Union[FileVolume, Error]] = await create_file_volume.asyncio(
        client=client,
        src_format=FileImportFormat.DAE,
        body=bytes("some bytes", "utf-8"),
    )

    # OR run async with more info
    response: Response[
        Optional[Union[FileVolume, Error]]
    ] = await create_file_volume.asyncio_detailed(
        client=client,
        src_format=FileImportFormat.DAE,
        body=bytes("some bytes", "utf-8"),
    )


@pytest.mark.skip
def test_logout():
    # Create our client.
    client = ClientFromEnv()

    result: Optional[Error] = logout.sync(
        client=client,
    )

    if isinstance(result, Error) or result is None:
        print(result)
        raise Exception("Error in response")

    body: Error = result
    print(body)

    # OR if you need more info (e.g. status_code)
    response: Response[Optional[Error]] = logout.sync_detailed(
        client=client,
    )


# OR run async
@pytest.mark.asyncio
@pytest.mark.skip
async def test_logout_async():
    # Create our client.
    client = ClientFromEnv()

    result: Optional[Error] = await logout.asyncio(
        client=client,
    )

    # OR run async with more info
    response: Response[Optional[Error]] = await logout.asyncio_detailed(
        client=client,
    )


@pytest.mark.skip
def test_cmd():
    # Create our client.
    client = ClientFromEnv()

    cmd.sync(
        client=client,
        body=ModelingCmdReq(
            cmd=ModelingCmd.START_PATH,
            cmd_id=ModelingCmdId("<uuid>"),
            file_id="<string>",
        ),
    )

    # OR if you need more info (e.g. status_code)
    cmd.sync_detailed(
        client=client,
        body=ModelingCmdReq(
            cmd=ModelingCmd.START_PATH,
            cmd_id=ModelingCmdId("<uuid>"),
            file_id="<string>",
        ),
    )


# OR run async
@pytest.mark.asyncio
@pytest.mark.skip
async def test_cmd_async():
    # Create our client.
    client = ClientFromEnv()

    await cmd.asyncio(
        client=client,
        body=ModelingCmdReq(
            cmd=ModelingCmd.START_PATH,
            cmd_id=ModelingCmdId("<uuid>"),
            file_id="<string>",
        ),
    )

    # OR run async with more info
    await cmd.asyncio_detailed(
        client=client,
        body=ModelingCmdReq(
            cmd=ModelingCmd.START_PATH,
            cmd_id=ModelingCmdId("<uuid>"),
            file_id="<string>",
        ),
    )


@pytest.mark.skip
def test_cmd_batch():
    # Create our client.
    client = ClientFromEnv()

    result: Optional[Union[ModelingOutcomes, Error]] = cmd_batch.sync(
        client=client,
        body=ModelingCmdReqBatch(
            cmds={
                "<string>": ModelingCmdReq(
                    cmd=ModelingCmd.START_PATH,
                    cmd_id=ModelingCmdId("<uuid>"),
                    file_id="<string>",
                )
            },
            file_id="<string>",
        ),
    )

    if isinstance(result, Error) or result is None:
        print(result)
        raise Exception("Error in response")

    body: ModelingOutcomes = result
    print(body)

    # OR if you need more info (e.g. status_code)
    response: Response[
        Optional[Union[ModelingOutcomes, Error]]
    ] = cmd_batch.sync_detailed(
        client=client,
        body=ModelingCmdReqBatch(
            cmds={
                "<string>": ModelingCmdReq(
                    cmd=ModelingCmd.START_PATH,
                    cmd_id=ModelingCmdId("<uuid>"),
                    file_id="<string>",
                )
            },
            file_id="<string>",
        ),
    )


# OR run async
@pytest.mark.asyncio
@pytest.mark.skip
async def test_cmd_batch_async():
    # Create our client.
    client = ClientFromEnv()

    result: Optional[Union[ModelingOutcomes, Error]] = await cmd_batch.asyncio(
        client=client,
        body=ModelingCmdReqBatch(
            cmds={
                "<string>": ModelingCmdReq(
                    cmd=ModelingCmd.START_PATH,
                    cmd_id=ModelingCmdId("<uuid>"),
                    file_id="<string>",
                )
            },
            file_id="<string>",
        ),
    )

    # OR run async with more info
    response: Response[
        Optional[Union[ModelingOutcomes, Error]]
    ] = await cmd_batch.asyncio_detailed(
        client=client,
        body=ModelingCmdReqBatch(
            cmds={
                "<string>": ModelingCmdReq(
                    cmd=ModelingCmd.START_PATH,
                    cmd_id=ModelingCmdId("<uuid>"),
                    file_id="<string>",
                )
            },
            file_id="<string>",
        ),
    )


@pytest.mark.skip
def test_get_openai_schema():
    # Create our client.
    client = ClientFromEnv()

    get_openai_schema.sync(
        client=client,
    )

    # OR if you need more info (e.g. status_code)
    get_openai_schema.sync_detailed(
        client=client,
    )


# OR run async
@pytest.mark.asyncio
@pytest.mark.skip
async def test_get_openai_schema_async():
    # Create our client.
    client = ClientFromEnv()

    await get_openai_schema.asyncio(
        client=client,
    )

    # OR run async with more info
    await get_openai_schema.asyncio_detailed(
        client=client,
    )


@pytest.mark.skip
def test_ping():
    # Create our client.
    client = ClientFromEnv()

    result: Optional[Union[Pong, Error]] = ping.sync(
        client=client,
    )

    if isinstance(result, Error) or result is None:
        print(result)
        raise Exception("Error in response")

    body: Pong = result
    print(body)

    # OR if you need more info (e.g. status_code)
    response: Response[Optional[Union[Pong, Error]]] = ping.sync_detailed(
        client=client,
    )


# OR run async
@pytest.mark.asyncio
@pytest.mark.skip
async def test_ping_async():
    # Create our client.
    client = ClientFromEnv()

    result: Optional[Union[Pong, Error]] = await ping.asyncio(
        client=client,
    )

    # OR run async with more info
    response: Response[Optional[Union[Pong, Error]]] = await ping.asyncio_detailed(
        client=client,
    )


@pytest.mark.skip
def test_get_angle_unit_conversion():
    # Create our client.
    client = ClientFromEnv()

    result: Optional[
        Union[UnitAngleConversion, Error]
    ] = get_angle_unit_conversion.sync(
        client=client,
        input_unit=UnitAngle.DEGREES,
        output_unit=UnitAngle.DEGREES,
        value=3.14,
    )

    if isinstance(result, Error) or result is None:
        print(result)
        raise Exception("Error in response")

    body: UnitAngleConversion = result
    print(body)

    # OR if you need more info (e.g. status_code)
    response: Response[
        Optional[Union[UnitAngleConversion, Error]]
    ] = get_angle_unit_conversion.sync_detailed(
        client=client,
        input_unit=UnitAngle.DEGREES,
        output_unit=UnitAngle.DEGREES,
        value=3.14,
    )


# OR run async
@pytest.mark.asyncio
@pytest.mark.skip
async def test_get_angle_unit_conversion_async():
    # Create our client.
    client = ClientFromEnv()

    result: Optional[
        Union[UnitAngleConversion, Error]
    ] = await get_angle_unit_conversion.asyncio(
        client=client,
        input_unit=UnitAngle.DEGREES,
        output_unit=UnitAngle.DEGREES,
        value=3.14,
    )

    # OR run async with more info
    response: Response[
        Optional[Union[UnitAngleConversion, Error]]
    ] = await get_angle_unit_conversion.asyncio_detailed(
        client=client,
        input_unit=UnitAngle.DEGREES,
        output_unit=UnitAngle.DEGREES,
        value=3.14,
    )


@pytest.mark.skip
def test_get_area_unit_conversion():
    # Create our client.
    client = ClientFromEnv()

    result: Optional[Union[UnitAreaConversion, Error]] = get_area_unit_conversion.sync(
        client=client,
        input_unit=UnitArea.ACRES,
        output_unit=UnitArea.ACRES,
        value=3.14,
    )

    if isinstance(result, Error) or result is None:
        print(result)
        raise Exception("Error in response")

    body: UnitAreaConversion = result
    print(body)

    # OR if you need more info (e.g. status_code)
    response: Response[
        Optional[Union[UnitAreaConversion, Error]]
    ] = get_area_unit_conversion.sync_detailed(
        client=client,
        input_unit=UnitArea.ACRES,
        output_unit=UnitArea.ACRES,
        value=3.14,
    )


# OR run async
@pytest.mark.asyncio
@pytest.mark.skip
async def test_get_area_unit_conversion_async():
    # Create our client.
    client = ClientFromEnv()

    result: Optional[
        Union[UnitAreaConversion, Error]
    ] = await get_area_unit_conversion.asyncio(
        client=client,
        input_unit=UnitArea.ACRES,
        output_unit=UnitArea.ACRES,
        value=3.14,
    )

    # OR run async with more info
    response: Response[
        Optional[Union[UnitAreaConversion, Error]]
    ] = await get_area_unit_conversion.asyncio_detailed(
        client=client,
        input_unit=UnitArea.ACRES,
        output_unit=UnitArea.ACRES,
        value=3.14,
    )


@pytest.mark.skip
def test_get_current_unit_conversion():
    # Create our client.
    client = ClientFromEnv()

    result: Optional[
        Union[UnitCurrentConversion, Error]
    ] = get_current_unit_conversion.sync(
        client=client,
        input_unit=UnitCurrent.AMPERES,
        output_unit=UnitCurrent.AMPERES,
        value=3.14,
    )

    if isinstance(result, Error) or result is None:
        print(result)
        raise Exception("Error in response")

    body: UnitCurrentConversion = result
    print(body)

    # OR if you need more info (e.g. status_code)
    response: Response[
        Optional[Union[UnitCurrentConversion, Error]]
    ] = get_current_unit_conversion.sync_detailed(
        client=client,
        input_unit=UnitCurrent.AMPERES,
        output_unit=UnitCurrent.AMPERES,
        value=3.14,
    )


# OR run async
@pytest.mark.asyncio
@pytest.mark.skip
async def test_get_current_unit_conversion_async():
    # Create our client.
    client = ClientFromEnv()

    result: Optional[
        Union[UnitCurrentConversion, Error]
    ] = await get_current_unit_conversion.asyncio(
        client=client,
        input_unit=UnitCurrent.AMPERES,
        output_unit=UnitCurrent.AMPERES,
        value=3.14,
    )

    # OR run async with more info
    response: Response[
        Optional[Union[UnitCurrentConversion, Error]]
    ] = await get_current_unit_conversion.asyncio_detailed(
        client=client,
        input_unit=UnitCurrent.AMPERES,
        output_unit=UnitCurrent.AMPERES,
        value=3.14,
    )


@pytest.mark.skip
def test_get_energy_unit_conversion():
    # Create our client.
    client = ClientFromEnv()

    result: Optional[
        Union[UnitEnergyConversion, Error]
    ] = get_energy_unit_conversion.sync(
        client=client,
        input_unit=UnitEnergy.BTU,
        output_unit=UnitEnergy.BTU,
        value=3.14,
    )

    if isinstance(result, Error) or result is None:
        print(result)
        raise Exception("Error in response")

    body: UnitEnergyConversion = result
    print(body)

    # OR if you need more info (e.g. status_code)
    response: Response[
        Optional[Union[UnitEnergyConversion, Error]]
    ] = get_energy_unit_conversion.sync_detailed(
        client=client,
        input_unit=UnitEnergy.BTU,
        output_unit=UnitEnergy.BTU,
        value=3.14,
    )


# OR run async
@pytest.mark.asyncio
@pytest.mark.skip
async def test_get_energy_unit_conversion_async():
    # Create our client.
    client = ClientFromEnv()

    result: Optional[
        Union[UnitEnergyConversion, Error]
    ] = await get_energy_unit_conversion.asyncio(
        client=client,
        input_unit=UnitEnergy.BTU,
        output_unit=UnitEnergy.BTU,
        value=3.14,
    )

    # OR run async with more info
    response: Response[
        Optional[Union[UnitEnergyConversion, Error]]
    ] = await get_energy_unit_conversion.asyncio_detailed(
        client=client,
        input_unit=UnitEnergy.BTU,
        output_unit=UnitEnergy.BTU,
        value=3.14,
    )


@pytest.mark.skip
def test_get_force_unit_conversion():
    # Create our client.
    client = ClientFromEnv()

    result: Optional[
        Union[UnitForceConversion, Error]
    ] = get_force_unit_conversion.sync(
        client=client,
        input_unit=UnitForce.DYNES,
        output_unit=UnitForce.DYNES,
        value=3.14,
    )

    if isinstance(result, Error) or result is None:
        print(result)
        raise Exception("Error in response")

    body: UnitForceConversion = result
    print(body)

    # OR if you need more info (e.g. status_code)
    response: Response[
        Optional[Union[UnitForceConversion, Error]]
    ] = get_force_unit_conversion.sync_detailed(
        client=client,
        input_unit=UnitForce.DYNES,
        output_unit=UnitForce.DYNES,
        value=3.14,
    )


# OR run async
@pytest.mark.asyncio
@pytest.mark.skip
async def test_get_force_unit_conversion_async():
    # Create our client.
    client = ClientFromEnv()

    result: Optional[
        Union[UnitForceConversion, Error]
    ] = await get_force_unit_conversion.asyncio(
        client=client,
        input_unit=UnitForce.DYNES,
        output_unit=UnitForce.DYNES,
        value=3.14,
    )

    # OR run async with more info
    response: Response[
        Optional[Union[UnitForceConversion, Error]]
    ] = await get_force_unit_conversion.asyncio_detailed(
        client=client,
        input_unit=UnitForce.DYNES,
        output_unit=UnitForce.DYNES,
        value=3.14,
    )


@pytest.mark.skip
def test_get_frequency_unit_conversion():
    # Create our client.
    client = ClientFromEnv()

    result: Optional[
        Union[UnitFrequencyConversion, Error]
    ] = get_frequency_unit_conversion.sync(
        client=client,
        input_unit=UnitFrequency.GIGAHERTZ,
        output_unit=UnitFrequency.GIGAHERTZ,
        value=3.14,
    )

    if isinstance(result, Error) or result is None:
        print(result)
        raise Exception("Error in response")

    body: UnitFrequencyConversion = result
    print(body)

    # OR if you need more info (e.g. status_code)
    response: Response[
        Optional[Union[UnitFrequencyConversion, Error]]
    ] = get_frequency_unit_conversion.sync_detailed(
        client=client,
        input_unit=UnitFrequency.GIGAHERTZ,
        output_unit=UnitFrequency.GIGAHERTZ,
        value=3.14,
    )


# OR run async
@pytest.mark.asyncio
@pytest.mark.skip
async def test_get_frequency_unit_conversion_async():
    # Create our client.
    client = ClientFromEnv()

    result: Optional[
        Union[UnitFrequencyConversion, Error]
    ] = await get_frequency_unit_conversion.asyncio(
        client=client,
        input_unit=UnitFrequency.GIGAHERTZ,
        output_unit=UnitFrequency.GIGAHERTZ,
        value=3.14,
    )

    # OR run async with more info
    response: Response[
        Optional[Union[UnitFrequencyConversion, Error]]
    ] = await get_frequency_unit_conversion.asyncio_detailed(
        client=client,
        input_unit=UnitFrequency.GIGAHERTZ,
        output_unit=UnitFrequency.GIGAHERTZ,
        value=3.14,
    )


@pytest.mark.skip
def test_get_length_unit_conversion():
    # Create our client.
    client = ClientFromEnv()

    result: Optional[
        Union[UnitLengthConversion, Error]
    ] = get_length_unit_conversion.sync(
        client=client,
        input_unit=UnitLength.CENTIMETRES,
        output_unit=UnitLength.CENTIMETRES,
        value=3.14,
    )

    if isinstance(result, Error) or result is None:
        print(result)
        raise Exception("Error in response")

    body: UnitLengthConversion = result
    print(body)

    # OR if you need more info (e.g. status_code)
    response: Response[
        Optional[Union[UnitLengthConversion, Error]]
    ] = get_length_unit_conversion.sync_detailed(
        client=client,
        input_unit=UnitLength.CENTIMETRES,
        output_unit=UnitLength.CENTIMETRES,
        value=3.14,
    )


# OR run async
@pytest.mark.asyncio
@pytest.mark.skip
async def test_get_length_unit_conversion_async():
    # Create our client.
    client = ClientFromEnv()

    result: Optional[
        Union[UnitLengthConversion, Error]
    ] = await get_length_unit_conversion.asyncio(
        client=client,
        input_unit=UnitLength.CENTIMETRES,
        output_unit=UnitLength.CENTIMETRES,
        value=3.14,
    )

    # OR run async with more info
    response: Response[
        Optional[Union[UnitLengthConversion, Error]]
    ] = await get_length_unit_conversion.asyncio_detailed(
        client=client,
        input_unit=UnitLength.CENTIMETRES,
        output_unit=UnitLength.CENTIMETRES,
        value=3.14,
    )


@pytest.mark.skip
def test_get_mass_unit_conversion():
    # Create our client.
    client = ClientFromEnv()

    result: Optional[Union[UnitMassConversion, Error]] = get_mass_unit_conversion.sync(
        client=client,
        input_unit=UnitMass.CARATS,
        output_unit=UnitMass.CARATS,
        value=3.14,
    )

    if isinstance(result, Error) or result is None:
        print(result)
        raise Exception("Error in response")

    body: UnitMassConversion = result
    print(body)

    # OR if you need more info (e.g. status_code)
    response: Response[
        Optional[Union[UnitMassConversion, Error]]
    ] = get_mass_unit_conversion.sync_detailed(
        client=client,
        input_unit=UnitMass.CARATS,
        output_unit=UnitMass.CARATS,
        value=3.14,
    )


# OR run async
@pytest.mark.asyncio
@pytest.mark.skip
async def test_get_mass_unit_conversion_async():
    # Create our client.
    client = ClientFromEnv()

    result: Optional[
        Union[UnitMassConversion, Error]
    ] = await get_mass_unit_conversion.asyncio(
        client=client,
        input_unit=UnitMass.CARATS,
        output_unit=UnitMass.CARATS,
        value=3.14,
    )

    # OR run async with more info
    response: Response[
        Optional[Union[UnitMassConversion, Error]]
    ] = await get_mass_unit_conversion.asyncio_detailed(
        client=client,
        input_unit=UnitMass.CARATS,
        output_unit=UnitMass.CARATS,
        value=3.14,
    )


@pytest.mark.skip
def test_get_power_unit_conversion():
    # Create our client.
    client = ClientFromEnv()

    result: Optional[
        Union[UnitPowerConversion, Error]
    ] = get_power_unit_conversion.sync(
        client=client,
        input_unit=UnitPower.BTU_PER_MINUTE,
        output_unit=UnitPower.BTU_PER_MINUTE,
        value=3.14,
    )

    if isinstance(result, Error) or result is None:
        print(result)
        raise Exception("Error in response")

    body: UnitPowerConversion = result
    print(body)

    # OR if you need more info (e.g. status_code)
    response: Response[
        Optional[Union[UnitPowerConversion, Error]]
    ] = get_power_unit_conversion.sync_detailed(
        client=client,
        input_unit=UnitPower.BTU_PER_MINUTE,
        output_unit=UnitPower.BTU_PER_MINUTE,
        value=3.14,
    )


# OR run async
@pytest.mark.asyncio
@pytest.mark.skip
async def test_get_power_unit_conversion_async():
    # Create our client.
    client = ClientFromEnv()

    result: Optional[
        Union[UnitPowerConversion, Error]
    ] = await get_power_unit_conversion.asyncio(
        client=client,
        input_unit=UnitPower.BTU_PER_MINUTE,
        output_unit=UnitPower.BTU_PER_MINUTE,
        value=3.14,
    )

    # OR run async with more info
    response: Response[
        Optional[Union[UnitPowerConversion, Error]]
    ] = await get_power_unit_conversion.asyncio_detailed(
        client=client,
        input_unit=UnitPower.BTU_PER_MINUTE,
        output_unit=UnitPower.BTU_PER_MINUTE,
        value=3.14,
    )


@pytest.mark.skip
def test_get_pressure_unit_conversion():
    # Create our client.
    client = ClientFromEnv()

    result: Optional[
        Union[UnitPressureConversion, Error]
    ] = get_pressure_unit_conversion.sync(
        client=client,
        input_unit=UnitPressure.ATMOSPHERES,
        output_unit=UnitPressure.ATMOSPHERES,
        value=3.14,
    )

    if isinstance(result, Error) or result is None:
        print(result)
        raise Exception("Error in response")

    body: UnitPressureConversion = result
    print(body)

    # OR if you need more info (e.g. status_code)
    response: Response[
        Optional[Union[UnitPressureConversion, Error]]
    ] = get_pressure_unit_conversion.sync_detailed(
        client=client,
        input_unit=UnitPressure.ATMOSPHERES,
        output_unit=UnitPressure.ATMOSPHERES,
        value=3.14,
    )


# OR run async
@pytest.mark.asyncio
@pytest.mark.skip
async def test_get_pressure_unit_conversion_async():
    # Create our client.
    client = ClientFromEnv()

    result: Optional[
        Union[UnitPressureConversion, Error]
    ] = await get_pressure_unit_conversion.asyncio(
        client=client,
        input_unit=UnitPressure.ATMOSPHERES,
        output_unit=UnitPressure.ATMOSPHERES,
        value=3.14,
    )

    # OR run async with more info
    response: Response[
        Optional[Union[UnitPressureConversion, Error]]
    ] = await get_pressure_unit_conversion.asyncio_detailed(
        client=client,
        input_unit=UnitPressure.ATMOSPHERES,
        output_unit=UnitPressure.ATMOSPHERES,
        value=3.14,
    )


@pytest.mark.skip
def test_get_temperature_unit_conversion():
    # Create our client.
    client = ClientFromEnv()

    result: Optional[
        Union[UnitTemperatureConversion, Error]
    ] = get_temperature_unit_conversion.sync(
        client=client,
        input_unit=UnitTemperature.CELSIUS,
        output_unit=UnitTemperature.CELSIUS,
        value=3.14,
    )

    if isinstance(result, Error) or result is None:
        print(result)
        raise Exception("Error in response")

    body: UnitTemperatureConversion = result
    print(body)

    # OR if you need more info (e.g. status_code)
    response: Response[
        Optional[Union[UnitTemperatureConversion, Error]]
    ] = get_temperature_unit_conversion.sync_detailed(
        client=client,
        input_unit=UnitTemperature.CELSIUS,
        output_unit=UnitTemperature.CELSIUS,
        value=3.14,
    )


# OR run async
@pytest.mark.asyncio
@pytest.mark.skip
async def test_get_temperature_unit_conversion_async():
    # Create our client.
    client = ClientFromEnv()

    result: Optional[
        Union[UnitTemperatureConversion, Error]
    ] = await get_temperature_unit_conversion.asyncio(
        client=client,
        input_unit=UnitTemperature.CELSIUS,
        output_unit=UnitTemperature.CELSIUS,
        value=3.14,
    )

    # OR run async with more info
    response: Response[
        Optional[Union[UnitTemperatureConversion, Error]]
    ] = await get_temperature_unit_conversion.asyncio_detailed(
        client=client,
        input_unit=UnitTemperature.CELSIUS,
        output_unit=UnitTemperature.CELSIUS,
        value=3.14,
    )


@pytest.mark.skip
def test_get_torque_unit_conversion():
    # Create our client.
    client = ClientFromEnv()

    result: Optional[
        Union[UnitTorqueConversion, Error]
    ] = get_torque_unit_conversion.sync(
        client=client,
        input_unit=UnitTorque.NEWTON_METRES,
        output_unit=UnitTorque.NEWTON_METRES,
        value=3.14,
    )

    if isinstance(result, Error) or result is None:
        print(result)
        raise Exception("Error in response")

    body: UnitTorqueConversion = result
    print(body)

    # OR if you need more info (e.g. status_code)
    response: Response[
        Optional[Union[UnitTorqueConversion, Error]]
    ] = get_torque_unit_conversion.sync_detailed(
        client=client,
        input_unit=UnitTorque.NEWTON_METRES,
        output_unit=UnitTorque.NEWTON_METRES,
        value=3.14,
    )


# OR run async
@pytest.mark.asyncio
@pytest.mark.skip
async def test_get_torque_unit_conversion_async():
    # Create our client.
    client = ClientFromEnv()

    result: Optional[
        Union[UnitTorqueConversion, Error]
    ] = await get_torque_unit_conversion.asyncio(
        client=client,
        input_unit=UnitTorque.NEWTON_METRES,
        output_unit=UnitTorque.NEWTON_METRES,
        value=3.14,
    )

    # OR run async with more info
    response: Response[
        Optional[Union[UnitTorqueConversion, Error]]
    ] = await get_torque_unit_conversion.asyncio_detailed(
        client=client,
        input_unit=UnitTorque.NEWTON_METRES,
        output_unit=UnitTorque.NEWTON_METRES,
        value=3.14,
    )


@pytest.mark.skip
def test_get_volume_unit_conversion():
    # Create our client.
    client = ClientFromEnv()

    result: Optional[
        Union[UnitVolumeConversion, Error]
    ] = get_volume_unit_conversion.sync(
        client=client,
        input_unit=UnitVolume.CUBIC_CENTIMETRES,
        output_unit=UnitVolume.CUBIC_CENTIMETRES,
        value=3.14,
    )

    if isinstance(result, Error) or result is None:
        print(result)
        raise Exception("Error in response")

    body: UnitVolumeConversion = result
    print(body)

    # OR if you need more info (e.g. status_code)
    response: Response[
        Optional[Union[UnitVolumeConversion, Error]]
    ] = get_volume_unit_conversion.sync_detailed(
        client=client,
        input_unit=UnitVolume.CUBIC_CENTIMETRES,
        output_unit=UnitVolume.CUBIC_CENTIMETRES,
        value=3.14,
    )


# OR run async
@pytest.mark.asyncio
@pytest.mark.skip
async def test_get_volume_unit_conversion_async():
    # Create our client.
    client = ClientFromEnv()

    result: Optional[
        Union[UnitVolumeConversion, Error]
    ] = await get_volume_unit_conversion.asyncio(
        client=client,
        input_unit=UnitVolume.CUBIC_CENTIMETRES,
        output_unit=UnitVolume.CUBIC_CENTIMETRES,
        value=3.14,
    )

    # OR run async with more info
    response: Response[
        Optional[Union[UnitVolumeConversion, Error]]
    ] = await get_volume_unit_conversion.asyncio_detailed(
        client=client,
        input_unit=UnitVolume.CUBIC_CENTIMETRES,
        output_unit=UnitVolume.CUBIC_CENTIMETRES,
        value=3.14,
    )


@pytest.mark.skip
def test_delete_user_self():
    # Create our client.
    client = ClientFromEnv()

    result: Optional[Error] = delete_user_self.sync(
        client=client,
    )

    if isinstance(result, Error) or result is None:
        print(result)
        raise Exception("Error in response")

    body: Error = result
    print(body)

    # OR if you need more info (e.g. status_code)
    response: Response[Optional[Error]] = delete_user_self.sync_detailed(
        client=client,
    )


# OR run async
@pytest.mark.asyncio
@pytest.mark.skip
async def test_delete_user_self_async():
    # Create our client.
    client = ClientFromEnv()

    result: Optional[Error] = await delete_user_self.asyncio(
        client=client,
    )

    # OR run async with more info
    response: Response[Optional[Error]] = await delete_user_self.asyncio_detailed(
        client=client,
    )


@pytest.mark.skip
def test_get_user_self():
    # Create our client.
    client = ClientFromEnv()

    result: Optional[Union[User, Error]] = get_user_self.sync(
        client=client,
    )

    if isinstance(result, Error) or result is None:
        print(result)
        raise Exception("Error in response")

    body: User = result
    print(body)

    # OR if you need more info (e.g. status_code)
    response: Response[Optional[Union[User, Error]]] = get_user_self.sync_detailed(
        client=client,
    )


# OR run async
@pytest.mark.asyncio
@pytest.mark.skip
async def test_get_user_self_async():
    # Create our client.
    client = ClientFromEnv()

    result: Optional[Union[User, Error]] = await get_user_self.asyncio(
        client=client,
    )

    # OR run async with more info
    response: Response[
        Optional[Union[User, Error]]
    ] = await get_user_self.asyncio_detailed(
        client=client,
    )


@pytest.mark.skip
def test_update_user_self():
    # Create our client.
    client = ClientFromEnv()

    result: Optional[Union[User, Error]] = update_user_self.sync(
        client=client,
        body=UpdateUser(
            company="<string>",
            discord="<string>",
            first_name="<string>",
            github="<string>",
            last_name="<string>",
            phone="<string>",
        ),
    )

    if isinstance(result, Error) or result is None:
        print(result)
        raise Exception("Error in response")

    body: User = result
    print(body)

    # OR if you need more info (e.g. status_code)
    response: Response[Optional[Union[User, Error]]] = update_user_self.sync_detailed(
        client=client,
        body=UpdateUser(
            company="<string>",
            discord="<string>",
            first_name="<string>",
            github="<string>",
            last_name="<string>",
            phone="<string>",
        ),
    )


# OR run async
@pytest.mark.asyncio
@pytest.mark.skip
async def test_update_user_self_async():
    # Create our client.
    client = ClientFromEnv()

    result: Optional[Union[User, Error]] = await update_user_self.asyncio(
        client=client,
        body=UpdateUser(
            company="<string>",
            discord="<string>",
            first_name="<string>",
            github="<string>",
            last_name="<string>",
            phone="<string>",
        ),
    )

    # OR run async with more info
    response: Response[
        Optional[Union[User, Error]]
    ] = await update_user_self.asyncio_detailed(
        client=client,
        body=UpdateUser(
            company="<string>",
            discord="<string>",
            first_name="<string>",
            github="<string>",
            last_name="<string>",
            phone="<string>",
        ),
    )


@pytest.mark.skip
def test_user_list_api_calls():
    # Create our client.
    client = ClientFromEnv()

    result: Optional[
        Union[ApiCallWithPriceResultsPage, Error]
    ] = user_list_api_calls.sync(
        client=client,
        sort_by=CreatedAtSortMode.CREATED_AT_ASCENDING,
        limit=None,  # Optional[int]
        page_token=None,  # Optional[str]
    )

    if isinstance(result, Error) or result is None:
        print(result)
        raise Exception("Error in response")

    body: ApiCallWithPriceResultsPage = result
    print(body)

    # OR if you need more info (e.g. status_code)
    response: Response[
        Optional[Union[ApiCallWithPriceResultsPage, Error]]
    ] = user_list_api_calls.sync_detailed(
        client=client,
        sort_by=CreatedAtSortMode.CREATED_AT_ASCENDING,
        limit=None,  # Optional[int]
        page_token=None,  # Optional[str]
    )


# OR run async
@pytest.mark.asyncio
@pytest.mark.skip
async def test_user_list_api_calls_async():
    # Create our client.
    client = ClientFromEnv()

    result: Optional[
        Union[ApiCallWithPriceResultsPage, Error]
    ] = await user_list_api_calls.asyncio(
        client=client,
        sort_by=CreatedAtSortMode.CREATED_AT_ASCENDING,
        limit=None,  # Optional[int]
        page_token=None,  # Optional[str]
    )

    # OR run async with more info
    response: Response[
        Optional[Union[ApiCallWithPriceResultsPage, Error]]
    ] = await user_list_api_calls.asyncio_detailed(
        client=client,
        sort_by=CreatedAtSortMode.CREATED_AT_ASCENDING,
        limit=None,  # Optional[int]
        page_token=None,  # Optional[str]
    )


@pytest.mark.skip
def test_get_api_call_for_user():
    # Create our client.
    client = ClientFromEnv()

    result: Optional[Union[ApiCallWithPrice, Error]] = get_api_call_for_user.sync(
        client=client,
        id="<string>",
    )

    if isinstance(result, Error) or result is None:
        print(result)
        raise Exception("Error in response")

    body: ApiCallWithPrice = result
    print(body)

    # OR if you need more info (e.g. status_code)
    response: Response[
        Optional[Union[ApiCallWithPrice, Error]]
    ] = get_api_call_for_user.sync_detailed(
        client=client,
        id="<string>",
    )


# OR run async
@pytest.mark.asyncio
@pytest.mark.skip
async def test_get_api_call_for_user_async():
    # Create our client.
    client = ClientFromEnv()

    result: Optional[
        Union[ApiCallWithPrice, Error]
    ] = await get_api_call_for_user.asyncio(
        client=client,
        id="<string>",
    )

    # OR run async with more info
    response: Response[
        Optional[Union[ApiCallWithPrice, Error]]
    ] = await get_api_call_for_user.asyncio_detailed(
        client=client,
        id="<string>",
    )


@pytest.mark.skip
def test_list_api_tokens_for_user():
    # Create our client.
    client = ClientFromEnv()

    result: Optional[Union[ApiTokenResultsPage, Error]] = list_api_tokens_for_user.sync(
        client=client,
        sort_by=CreatedAtSortMode.CREATED_AT_ASCENDING,
        limit=None,  # Optional[int]
        page_token=None,  # Optional[str]
    )

    if isinstance(result, Error) or result is None:
        print(result)
        raise Exception("Error in response")

    body: ApiTokenResultsPage = result
    print(body)

    # OR if you need more info (e.g. status_code)
    response: Response[
        Optional[Union[ApiTokenResultsPage, Error]]
    ] = list_api_tokens_for_user.sync_detailed(
        client=client,
        sort_by=CreatedAtSortMode.CREATED_AT_ASCENDING,
        limit=None,  # Optional[int]
        page_token=None,  # Optional[str]
    )


# OR run async
@pytest.mark.asyncio
@pytest.mark.skip
async def test_list_api_tokens_for_user_async():
    # Create our client.
    client = ClientFromEnv()

    result: Optional[
        Union[ApiTokenResultsPage, Error]
    ] = await list_api_tokens_for_user.asyncio(
        client=client,
        sort_by=CreatedAtSortMode.CREATED_AT_ASCENDING,
        limit=None,  # Optional[int]
        page_token=None,  # Optional[str]
    )

    # OR run async with more info
    response: Response[
        Optional[Union[ApiTokenResultsPage, Error]]
    ] = await list_api_tokens_for_user.asyncio_detailed(
        client=client,
        sort_by=CreatedAtSortMode.CREATED_AT_ASCENDING,
        limit=None,  # Optional[int]
        page_token=None,  # Optional[str]
    )


@pytest.mark.skip
def test_create_api_token_for_user():
    # Create our client.
    client = ClientFromEnv()

    result: Optional[Union[ApiToken, Error]] = create_api_token_for_user.sync(
        client=client,
    )

    if isinstance(result, Error) or result is None:
        print(result)
        raise Exception("Error in response")

    body: ApiToken = result
    print(body)

    # OR if you need more info (e.g. status_code)
    response: Response[
        Optional[Union[ApiToken, Error]]
    ] = create_api_token_for_user.sync_detailed(
        client=client,
    )


# OR run async
@pytest.mark.asyncio
@pytest.mark.skip
async def test_create_api_token_for_user_async():
    # Create our client.
    client = ClientFromEnv()

    result: Optional[Union[ApiToken, Error]] = await create_api_token_for_user.asyncio(
        client=client,
    )

    # OR run async with more info
    response: Response[
        Optional[Union[ApiToken, Error]]
    ] = await create_api_token_for_user.asyncio_detailed(
        client=client,
    )


@pytest.mark.skip
def test_delete_api_token_for_user():
    # Create our client.
    client = ClientFromEnv()

    result: Optional[Error] = delete_api_token_for_user.sync(
        client=client,
        token="<uuid>",
    )

    if isinstance(result, Error) or result is None:
        print(result)
        raise Exception("Error in response")

    body: Error = result
    print(body)

    # OR if you need more info (e.g. status_code)
    response: Response[Optional[Error]] = delete_api_token_for_user.sync_detailed(
        client=client,
        token="<uuid>",
    )


# OR run async
@pytest.mark.asyncio
@pytest.mark.skip
async def test_delete_api_token_for_user_async():
    # Create our client.
    client = ClientFromEnv()

    result: Optional[Error] = await delete_api_token_for_user.asyncio(
        client=client,
        token="<uuid>",
    )

    # OR run async with more info
    response: Response[
        Optional[Error]
    ] = await delete_api_token_for_user.asyncio_detailed(
        client=client,
        token="<uuid>",
    )


@pytest.mark.skip
def test_get_api_token_for_user():
    # Create our client.
    client = ClientFromEnv()

    result: Optional[Union[ApiToken, Error]] = get_api_token_for_user.sync(
        client=client,
        token="<uuid>",
    )

    if isinstance(result, Error) or result is None:
        print(result)
        raise Exception("Error in response")

    body: ApiToken = result
    print(body)

    # OR if you need more info (e.g. status_code)
    response: Response[
        Optional[Union[ApiToken, Error]]
    ] = get_api_token_for_user.sync_detailed(
        client=client,
        token="<uuid>",
    )


# OR run async
@pytest.mark.asyncio
@pytest.mark.skip
async def test_get_api_token_for_user_async():
    # Create our client.
    client = ClientFromEnv()

    result: Optional[Union[ApiToken, Error]] = await get_api_token_for_user.asyncio(
        client=client,
        token="<uuid>",
    )

    # OR run async with more info
    response: Response[
        Optional[Union[ApiToken, Error]]
    ] = await get_api_token_for_user.asyncio_detailed(
        client=client,
        token="<uuid>",
    )


@pytest.mark.skip
def test_get_user_self_extended():
    # Create our client.
    client = ClientFromEnv()

    result: Optional[Union[ExtendedUser, Error]] = get_user_self_extended.sync(
        client=client,
    )

    if isinstance(result, Error) or result is None:
        print(result)
        raise Exception("Error in response")

    body: ExtendedUser = result
    print(body)

    # OR if you need more info (e.g. status_code)
    response: Response[
        Optional[Union[ExtendedUser, Error]]
    ] = get_user_self_extended.sync_detailed(
        client=client,
    )


# OR run async
@pytest.mark.asyncio
@pytest.mark.skip
async def test_get_user_self_extended_async():
    # Create our client.
    client = ClientFromEnv()

    result: Optional[Union[ExtendedUser, Error]] = await get_user_self_extended.asyncio(
        client=client,
    )

    # OR run async with more info
    response: Response[
        Optional[Union[ExtendedUser, Error]]
    ] = await get_user_self_extended.asyncio_detailed(
        client=client,
    )


@pytest.mark.skip
def test_get_user_front_hash_self():
    # Create our client.
    client = ClientFromEnv()

    get_user_front_hash_self.sync(
        client=client,
    )

    # OR if you need more info (e.g. status_code)
    get_user_front_hash_self.sync_detailed(
        client=client,
    )


# OR run async
@pytest.mark.asyncio
@pytest.mark.skip
async def test_get_user_front_hash_self_async():
    # Create our client.
    client = ClientFromEnv()

    await get_user_front_hash_self.asyncio(
        client=client,
    )

    # OR run async with more info
    await get_user_front_hash_self.asyncio_detailed(
        client=client,
    )


@pytest.mark.skip
def test_get_user_onboarding_self():
    # Create our client.
    client = ClientFromEnv()

    result: Optional[Union[Onboarding, Error]] = get_user_onboarding_self.sync(
        client=client,
    )

    if isinstance(result, Error) or result is None:
        print(result)
        raise Exception("Error in response")

    body: Onboarding = result
    print(body)

    # OR if you need more info (e.g. status_code)
    response: Response[
        Optional[Union[Onboarding, Error]]
    ] = get_user_onboarding_self.sync_detailed(
        client=client,
    )


# OR run async
@pytest.mark.asyncio
@pytest.mark.skip
async def test_get_user_onboarding_self_async():
    # Create our client.
    client = ClientFromEnv()

    result: Optional[Union[Onboarding, Error]] = await get_user_onboarding_self.asyncio(
        client=client,
    )

    # OR run async with more info
    response: Response[
        Optional[Union[Onboarding, Error]]
    ] = await get_user_onboarding_self.asyncio_detailed(
        client=client,
    )


@pytest.mark.skip
def test_delete_payment_information_for_user():
    # Create our client.
    client = ClientFromEnv()

    result: Optional[Error] = delete_payment_information_for_user.sync(
        client=client,
    )

    if isinstance(result, Error) or result is None:
        print(result)
        raise Exception("Error in response")

    body: Error = result
    print(body)

    # OR if you need more info (e.g. status_code)
    response: Response[
        Optional[Error]
    ] = delete_payment_information_for_user.sync_detailed(
        client=client,
    )


# OR run async
@pytest.mark.asyncio
@pytest.mark.skip
async def test_delete_payment_information_for_user_async():
    # Create our client.
    client = ClientFromEnv()

    result: Optional[Error] = await delete_payment_information_for_user.asyncio(
        client=client,
    )

    # OR run async with more info
    response: Response[
        Optional[Error]
    ] = await delete_payment_information_for_user.asyncio_detailed(
        client=client,
    )


@pytest.mark.skip
def test_get_payment_information_for_user():
    # Create our client.
    client = ClientFromEnv()

    result: Optional[Union[Customer, Error]] = get_payment_information_for_user.sync(
        client=client,
    )

    if isinstance(result, Error) or result is None:
        print(result)
        raise Exception("Error in response")

    body: Customer = result
    print(body)

    # OR if you need more info (e.g. status_code)
    response: Response[
        Optional[Union[Customer, Error]]
    ] = get_payment_information_for_user.sync_detailed(
        client=client,
    )


# OR run async
@pytest.mark.asyncio
@pytest.mark.skip
async def test_get_payment_information_for_user_async():
    # Create our client.
    client = ClientFromEnv()

    result: Optional[
        Union[Customer, Error]
    ] = await get_payment_information_for_user.asyncio(
        client=client,
    )

    # OR run async with more info
    response: Response[
        Optional[Union[Customer, Error]]
    ] = await get_payment_information_for_user.asyncio_detailed(
        client=client,
    )


@pytest.mark.skip
def test_create_payment_information_for_user():
    # Create our client.
    client = ClientFromEnv()

    result: Optional[Union[Customer, Error]] = create_payment_information_for_user.sync(
        client=client,
        body=BillingInfo(
            name="<string>",
            phone="<string>",
        ),
    )

    if isinstance(result, Error) or result is None:
        print(result)
        raise Exception("Error in response")

    body: Customer = result
    print(body)

    # OR if you need more info (e.g. status_code)
    response: Response[
        Optional[Union[Customer, Error]]
    ] = create_payment_information_for_user.sync_detailed(
        client=client,
        body=BillingInfo(
            name="<string>",
            phone="<string>",
        ),
    )


# OR run async
@pytest.mark.asyncio
@pytest.mark.skip
async def test_create_payment_information_for_user_async():
    # Create our client.
    client = ClientFromEnv()

    result: Optional[
        Union[Customer, Error]
    ] = await create_payment_information_for_user.asyncio(
        client=client,
        body=BillingInfo(
            name="<string>",
            phone="<string>",
        ),
    )

    # OR run async with more info
    response: Response[
        Optional[Union[Customer, Error]]
    ] = await create_payment_information_for_user.asyncio_detailed(
        client=client,
        body=BillingInfo(
            name="<string>",
            phone="<string>",
        ),
    )


@pytest.mark.skip
def test_update_payment_information_for_user():
    # Create our client.
    client = ClientFromEnv()

    result: Optional[Union[Customer, Error]] = update_payment_information_for_user.sync(
        client=client,
        body=BillingInfo(
            name="<string>",
            phone="<string>",
        ),
    )

    if isinstance(result, Error) or result is None:
        print(result)
        raise Exception("Error in response")

    body: Customer = result
    print(body)

    # OR if you need more info (e.g. status_code)
    response: Response[
        Optional[Union[Customer, Error]]
    ] = update_payment_information_for_user.sync_detailed(
        client=client,
        body=BillingInfo(
            name="<string>",
            phone="<string>",
        ),
    )


# OR run async
@pytest.mark.asyncio
@pytest.mark.skip
async def test_update_payment_information_for_user_async():
    # Create our client.
    client = ClientFromEnv()

    result: Optional[
        Union[Customer, Error]
    ] = await update_payment_information_for_user.asyncio(
        client=client,
        body=BillingInfo(
            name="<string>",
            phone="<string>",
        ),
    )

    # OR run async with more info
    response: Response[
        Optional[Union[Customer, Error]]
    ] = await update_payment_information_for_user.asyncio_detailed(
        client=client,
        body=BillingInfo(
            name="<string>",
            phone="<string>",
        ),
    )


@pytest.mark.skip
def test_get_payment_balance_for_user():
    # Create our client.
    client = ClientFromEnv()

    result: Optional[Union[CustomerBalance, Error]] = get_payment_balance_for_user.sync(
        client=client,
    )

    if isinstance(result, Error) or result is None:
        print(result)
        raise Exception("Error in response")

    body: CustomerBalance = result
    print(body)

    # OR if you need more info (e.g. status_code)
    response: Response[
        Optional[Union[CustomerBalance, Error]]
    ] = get_payment_balance_for_user.sync_detailed(
        client=client,
    )


# OR run async
@pytest.mark.asyncio
@pytest.mark.skip
async def test_get_payment_balance_for_user_async():
    # Create our client.
    client = ClientFromEnv()

    result: Optional[
        Union[CustomerBalance, Error]
    ] = await get_payment_balance_for_user.asyncio(
        client=client,
    )

    # OR run async with more info
    response: Response[
        Optional[Union[CustomerBalance, Error]]
    ] = await get_payment_balance_for_user.asyncio_detailed(
        client=client,
    )


@pytest.mark.skip
def test_create_payment_intent_for_user():
    # Create our client.
    client = ClientFromEnv()

    result: Optional[Union[PaymentIntent, Error]] = create_payment_intent_for_user.sync(
        client=client,
    )

    if isinstance(result, Error) or result is None:
        print(result)
        raise Exception("Error in response")

    body: PaymentIntent = result
    print(body)

    # OR if you need more info (e.g. status_code)
    response: Response[
        Optional[Union[PaymentIntent, Error]]
    ] = create_payment_intent_for_user.sync_detailed(
        client=client,
    )


# OR run async
@pytest.mark.asyncio
@pytest.mark.skip
async def test_create_payment_intent_for_user_async():
    # Create our client.
    client = ClientFromEnv()

    result: Optional[
        Union[PaymentIntent, Error]
    ] = await create_payment_intent_for_user.asyncio(
        client=client,
    )

    # OR run async with more info
    response: Response[
        Optional[Union[PaymentIntent, Error]]
    ] = await create_payment_intent_for_user.asyncio_detailed(
        client=client,
    )


@pytest.mark.skip
def test_list_invoices_for_user():
    # Create our client.
    client = ClientFromEnv()

    result: Optional[Union[List[Invoice], Error]] = list_invoices_for_user.sync(
        client=client,
    )

    if isinstance(result, Error) or result is None:
        print(result)
        raise Exception("Error in response")

    body: List[Invoice] = result
    print(body)

    # OR if you need more info (e.g. status_code)
    response: Response[
        Optional[Union[List[Invoice], Error]]
    ] = list_invoices_for_user.sync_detailed(
        client=client,
    )


# OR run async
@pytest.mark.asyncio
@pytest.mark.skip
async def test_list_invoices_for_user_async():
    # Create our client.
    client = ClientFromEnv()

    result: Optional[
        Union[List[Invoice], Error]
    ] = await list_invoices_for_user.asyncio(
        client=client,
    )

    # OR run async with more info
    response: Response[
        Optional[Union[List[Invoice], Error]]
    ] = await list_invoices_for_user.asyncio_detailed(
        client=client,
    )


@pytest.mark.skip
def test_list_payment_methods_for_user():
    # Create our client.
    client = ClientFromEnv()

    result: Optional[
        Union[List[PaymentMethod], Error]
    ] = list_payment_methods_for_user.sync(
        client=client,
    )

    if isinstance(result, Error) or result is None:
        print(result)
        raise Exception("Error in response")

    body: List[PaymentMethod] = result
    print(body)

    # OR if you need more info (e.g. status_code)
    response: Response[
        Optional[Union[List[PaymentMethod], Error]]
    ] = list_payment_methods_for_user.sync_detailed(
        client=client,
    )


# OR run async
@pytest.mark.asyncio
@pytest.mark.skip
async def test_list_payment_methods_for_user_async():
    # Create our client.
    client = ClientFromEnv()

    result: Optional[
        Union[List[PaymentMethod], Error]
    ] = await list_payment_methods_for_user.asyncio(
        client=client,
    )

    # OR run async with more info
    response: Response[
        Optional[Union[List[PaymentMethod], Error]]
    ] = await list_payment_methods_for_user.asyncio_detailed(
        client=client,
    )


@pytest.mark.skip
def test_delete_payment_method_for_user():
    # Create our client.
    client = ClientFromEnv()

    result: Optional[Error] = delete_payment_method_for_user.sync(
        client=client,
        id="<string>",
    )

    if isinstance(result, Error) or result is None:
        print(result)
        raise Exception("Error in response")

    body: Error = result
    print(body)

    # OR if you need more info (e.g. status_code)
    response: Response[Optional[Error]] = delete_payment_method_for_user.sync_detailed(
        client=client,
        id="<string>",
    )


# OR run async
@pytest.mark.asyncio
@pytest.mark.skip
async def test_delete_payment_method_for_user_async():
    # Create our client.
    client = ClientFromEnv()

    result: Optional[Error] = await delete_payment_method_for_user.asyncio(
        client=client,
        id="<string>",
    )

    # OR run async with more info
    response: Response[
        Optional[Error]
    ] = await delete_payment_method_for_user.asyncio_detailed(
        client=client,
        id="<string>",
    )


@pytest.mark.skip
def test_validate_customer_tax_information_for_user():
    # Create our client.
    client = ClientFromEnv()

    result: Optional[Error] = validate_customer_tax_information_for_user.sync(
        client=client,
    )

    if isinstance(result, Error) or result is None:
        print(result)
        raise Exception("Error in response")

    body: Error = result
    print(body)

    # OR if you need more info (e.g. status_code)
    response: Response[
        Optional[Error]
    ] = validate_customer_tax_information_for_user.sync_detailed(
        client=client,
    )


# OR run async
@pytest.mark.asyncio
@pytest.mark.skip
async def test_validate_customer_tax_information_for_user_async():
    # Create our client.
    client = ClientFromEnv()

    result: Optional[Error] = await validate_customer_tax_information_for_user.asyncio(
        client=client,
    )

    # OR run async with more info
    response: Response[
        Optional[Error]
    ] = await validate_customer_tax_information_for_user.asyncio_detailed(
        client=client,
    )


@pytest.mark.skip
def test_get_session_for_user():
    # Create our client.
    client = ClientFromEnv()

    result: Optional[Union[Session, Error]] = get_session_for_user.sync(
        client=client,
        token="<uuid>",
    )

    if isinstance(result, Error) or result is None:
        print(result)
        raise Exception("Error in response")

    body: Session = result
    print(body)

    # OR if you need more info (e.g. status_code)
    response: Response[
        Optional[Union[Session, Error]]
    ] = get_session_for_user.sync_detailed(
        client=client,
        token="<uuid>",
    )


# OR run async
@pytest.mark.asyncio
@pytest.mark.skip
async def test_get_session_for_user_async():
    # Create our client.
    client = ClientFromEnv()

    result: Optional[Union[Session, Error]] = await get_session_for_user.asyncio(
        client=client,
        token="<uuid>",
    )

    # OR run async with more info
    response: Response[
        Optional[Union[Session, Error]]
    ] = await get_session_for_user.asyncio_detailed(
        client=client,
        token="<uuid>",
    )


@pytest.mark.skip
def test_list_users():
    # Create our client.
    client = ClientFromEnv()

    result: Optional[Union[UserResultsPage, Error]] = list_users.sync(
        client=client,
        sort_by=CreatedAtSortMode.CREATED_AT_ASCENDING,
        limit=None,  # Optional[int]
        page_token=None,  # Optional[str]
    )

    if isinstance(result, Error) or result is None:
        print(result)
        raise Exception("Error in response")

    body: UserResultsPage = result
    print(body)

    # OR if you need more info (e.g. status_code)
    response: Response[
        Optional[Union[UserResultsPage, Error]]
    ] = list_users.sync_detailed(
        client=client,
        sort_by=CreatedAtSortMode.CREATED_AT_ASCENDING,
        limit=None,  # Optional[int]
        page_token=None,  # Optional[str]
    )


# OR run async
@pytest.mark.asyncio
@pytest.mark.skip
async def test_list_users_async():
    # Create our client.
    client = ClientFromEnv()

    result: Optional[Union[UserResultsPage, Error]] = await list_users.asyncio(
        client=client,
        sort_by=CreatedAtSortMode.CREATED_AT_ASCENDING,
        limit=None,  # Optional[int]
        page_token=None,  # Optional[str]
    )

    # OR run async with more info
    response: Response[
        Optional[Union[UserResultsPage, Error]]
    ] = await list_users.asyncio_detailed(
        client=client,
        sort_by=CreatedAtSortMode.CREATED_AT_ASCENDING,
        limit=None,  # Optional[int]
        page_token=None,  # Optional[str]
    )


@pytest.mark.skip
def test_list_users_extended():
    # Create our client.
    client = ClientFromEnv()

    result: Optional[Union[ExtendedUserResultsPage, Error]] = list_users_extended.sync(
        client=client,
        sort_by=CreatedAtSortMode.CREATED_AT_ASCENDING,
        limit=None,  # Optional[int]
        page_token=None,  # Optional[str]
    )

    if isinstance(result, Error) or result is None:
        print(result)
        raise Exception("Error in response")

    body: ExtendedUserResultsPage = result
    print(body)

    # OR if you need more info (e.g. status_code)
    response: Response[
        Optional[Union[ExtendedUserResultsPage, Error]]
    ] = list_users_extended.sync_detailed(
        client=client,
        sort_by=CreatedAtSortMode.CREATED_AT_ASCENDING,
        limit=None,  # Optional[int]
        page_token=None,  # Optional[str]
    )


# OR run async
@pytest.mark.asyncio
@pytest.mark.skip
async def test_list_users_extended_async():
    # Create our client.
    client = ClientFromEnv()

    result: Optional[
        Union[ExtendedUserResultsPage, Error]
    ] = await list_users_extended.asyncio(
        client=client,
        sort_by=CreatedAtSortMode.CREATED_AT_ASCENDING,
        limit=None,  # Optional[int]
        page_token=None,  # Optional[str]
    )

    # OR run async with more info
    response: Response[
        Optional[Union[ExtendedUserResultsPage, Error]]
    ] = await list_users_extended.asyncio_detailed(
        client=client,
        sort_by=CreatedAtSortMode.CREATED_AT_ASCENDING,
        limit=None,  # Optional[int]
        page_token=None,  # Optional[str]
    )


@pytest.mark.skip
def test_get_user_extended():
    # Create our client.
    client = ClientFromEnv()

    result: Optional[Union[ExtendedUser, Error]] = get_user_extended.sync(
        client=client,
        id="<string>",
    )

    if isinstance(result, Error) or result is None:
        print(result)
        raise Exception("Error in response")

    body: ExtendedUser = result
    print(body)

    # OR if you need more info (e.g. status_code)
    response: Response[
        Optional[Union[ExtendedUser, Error]]
    ] = get_user_extended.sync_detailed(
        client=client,
        id="<string>",
    )


# OR run async
@pytest.mark.asyncio
@pytest.mark.skip
async def test_get_user_extended_async():
    # Create our client.
    client = ClientFromEnv()

    result: Optional[Union[ExtendedUser, Error]] = await get_user_extended.asyncio(
        client=client,
        id="<string>",
    )

    # OR run async with more info
    response: Response[
        Optional[Union[ExtendedUser, Error]]
    ] = await get_user_extended.asyncio_detailed(
        client=client,
        id="<string>",
    )


@pytest.mark.skip
def test_get_user():
    # Create our client.
    client = ClientFromEnv()

    result: Optional[Union[User, Error]] = get_user.sync(
        client=client,
        id="<string>",
    )

    if isinstance(result, Error) or result is None:
        print(result)
        raise Exception("Error in response")

    body: User = result
    print(body)

    # OR if you need more info (e.g. status_code)
    response: Response[Optional[Union[User, Error]]] = get_user.sync_detailed(
        client=client,
        id="<string>",
    )


# OR run async
@pytest.mark.asyncio
@pytest.mark.skip
async def test_get_user_async():
    # Create our client.
    client = ClientFromEnv()

    result: Optional[Union[User, Error]] = await get_user.asyncio(
        client=client,
        id="<string>",
    )

    # OR run async with more info
    response: Response[Optional[Union[User, Error]]] = await get_user.asyncio_detailed(
        client=client,
        id="<string>",
    )


@pytest.mark.skip
def test_list_api_calls_for_user():
    # Create our client.
    client = ClientFromEnv()

    result: Optional[
        Union[ApiCallWithPriceResultsPage, Error]
    ] = list_api_calls_for_user.sync(
        client=client,
        id="<string>",
        sort_by=CreatedAtSortMode.CREATED_AT_ASCENDING,
        limit=None,  # Optional[int]
        page_token=None,  # Optional[str]
    )

    if isinstance(result, Error) or result is None:
        print(result)
        raise Exception("Error in response")

    body: ApiCallWithPriceResultsPage = result
    print(body)

    # OR if you need more info (e.g. status_code)
    response: Response[
        Optional[Union[ApiCallWithPriceResultsPage, Error]]
    ] = list_api_calls_for_user.sync_detailed(
        client=client,
        id="<string>",
        sort_by=CreatedAtSortMode.CREATED_AT_ASCENDING,
        limit=None,  # Optional[int]
        page_token=None,  # Optional[str]
    )


# OR run async
@pytest.mark.asyncio
@pytest.mark.skip
async def test_list_api_calls_for_user_async():
    # Create our client.
    client = ClientFromEnv()

    result: Optional[
        Union[ApiCallWithPriceResultsPage, Error]
    ] = await list_api_calls_for_user.asyncio(
        client=client,
        id="<string>",
        sort_by=CreatedAtSortMode.CREATED_AT_ASCENDING,
        limit=None,  # Optional[int]
        page_token=None,  # Optional[str]
    )

    # OR run async with more info
    response: Response[
        Optional[Union[ApiCallWithPriceResultsPage, Error]]
    ] = await list_api_calls_for_user.asyncio_detailed(
        client=client,
        id="<string>",
        sort_by=CreatedAtSortMode.CREATED_AT_ASCENDING,
        limit=None,  # Optional[int]
        page_token=None,  # Optional[str]
    )


@pytest.mark.skip
def test_create_executor_term():
    # Create our client.
    client = ClientFromEnv()

    create_executor_term.sync(
        client=client,
    )

    # OR if you need more info (e.g. status_code)
    create_executor_term.sync_detailed(
        client=client,
    )


# OR run async
@pytest.mark.asyncio
@pytest.mark.skip
async def test_create_executor_term_async():
    # Create our client.
    client = ClientFromEnv()

    await create_executor_term.asyncio(
        client=client,
    )

    # OR run async with more info
    await create_executor_term.asyncio_detailed(
        client=client,
    )


@pytest.mark.skip
def test_modeling_commands_ws():
    # Create our client.
    client = ClientFromEnv()

    modeling_commands_ws.sync(
        client=client,
    )

    # OR if you need more info (e.g. status_code)
    modeling_commands_ws.sync_detailed(
        client=client,
    )


# OR run async
@pytest.mark.asyncio
@pytest.mark.skip
async def test_modeling_commands_ws_async():
    # Create our client.
    client = ClientFromEnv()

    await modeling_commands_ws.asyncio(
        client=client,
    )

    # OR run async with more info
    await modeling_commands_ws.asyncio_detailed(
        client=client,
    )



from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

N = TypeVar("N", bound="Coupon")


@attr.s(auto_attribs=True)
class Coupon:
    """The resource representing a Coupon."""  # noqa: E501

    amount_off: Union[Unset, float] = UNSET
    deleted: Union[Unset, bool] = False
    id: Union[Unset, str] = UNSET
    percent_off: Union[Unset, float] = UNSET

    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        amount_off = self.amount_off
        deleted = self.deleted
        id = self.id
        percent_off = self.percent_off

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if amount_off is not UNSET:
            field_dict["amount_off"] = amount_off
        if deleted is not UNSET:
            field_dict["deleted"] = deleted
        if id is not UNSET:
            field_dict["id"] = id
        if percent_off is not UNSET:
            field_dict["percent_off"] = percent_off

        return field_dict

    @classmethod
    def from_dict(cls: Type[N], src_dict: Dict[str, Any]) -> N:
        d = src_dict.copy()
        amount_off = d.pop("amount_off", UNSET)

        deleted = d.pop("deleted", UNSET)

        id = d.pop("id", UNSET)

        percent_off = d.pop("percent_off", UNSET)

        coupon = cls(
            amount_off=amount_off,
            deleted=deleted,
            id=id,
            percent_off=percent_off,
        )

        coupon.additional_properties = d
        return coupon

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from enum import Enum


class AccountProvider(str, Enum):
    """An account provider."""  # noqa: E501

    """# The Google account provider. """  # noqa: E501
    GOOGLE = "google"
    """# The GitHub account provider. """  # noqa: E501
    GITHUB = "github"

    def __str__(self) -> str:
        return str(self.value)



from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..models.payment_method_card_checks import PaymentMethodCardChecks
from ..types import UNSET, Unset

N = TypeVar("N", bound="CardDetails")


@attr.s(auto_attribs=True)
class CardDetails:
    """The card details of a payment method."""  # noqa: E501

    brand: Union[Unset, str] = UNSET
    checks: Union[Unset, PaymentMethodCardChecks] = UNSET
    country: Union[Unset, str] = UNSET
    exp_month: Union[Unset, int] = UNSET
    exp_year: Union[Unset, int] = UNSET
    fingerprint: Union[Unset, str] = UNSET
    funding: Union[Unset, str] = UNSET
    last4: Union[Unset, str] = UNSET

    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        brand = self.brand
        if not isinstance(self.checks, Unset):
            checks = self.checks
        country = self.country
        exp_month = self.exp_month
        exp_year = self.exp_year
        fingerprint = self.fingerprint
        funding = self.funding
        last4 = self.last4

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if brand is not UNSET:
            field_dict["brand"] = brand
        if checks is not UNSET:
            field_dict["checks"] = checks
        if country is not UNSET:
            field_dict["country"] = country
        if exp_month is not UNSET:
            field_dict["exp_month"] = exp_month
        if exp_year is not UNSET:
            field_dict["exp_year"] = exp_year
        if fingerprint is not UNSET:
            field_dict["fingerprint"] = fingerprint
        if funding is not UNSET:
            field_dict["funding"] = funding
        if last4 is not UNSET:
            field_dict["last4"] = last4

        return field_dict

    @classmethod
    def from_dict(cls: Type[N], src_dict: Dict[str, Any]) -> N:
        d = src_dict.copy()
        brand = d.pop("brand", UNSET)

        _checks = d.pop("checks", UNSET)
        checks: Union[Unset, PaymentMethodCardChecks]
        if isinstance(_checks, Unset):
            checks = UNSET
        else:
            checks = PaymentMethodCardChecks(_checks)

        country = d.pop("country", UNSET)

        exp_month = d.pop("exp_month", UNSET)

        exp_year = d.pop("exp_year", UNSET)

        fingerprint = d.pop("fingerprint", UNSET)

        funding = d.pop("funding", UNSET)

        last4 = d.pop("last4", UNSET)

        card_details = cls(
            brand=brand,
            checks=checks,
            country=country,
            exp_month=exp_month,
            exp_year=exp_year,
            fingerprint=fingerprint,
            funding=funding,
            last4=last4,
        )

        card_details.additional_properties = d
        return card_details

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..models.modeling_cmd_id import ModelingCmdId
from ..types import UNSET, Unset
from .modeling_error import ModelingError

Success = Any


Error = ModelingError


E = TypeVar("E", bound="Cancelled")


@attr.s(auto_attribs=True)
class Cancelled:
    what_failed: Union[Unset, ModelingCmdId] = UNSET

    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        if not isinstance(self.what_failed, Unset):
            what_failed = self.what_failed

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if what_failed is not UNSET:
            field_dict["what_failed"] = what_failed

        return field_dict

    @classmethod
    def from_dict(cls: Type[E], src_dict: Dict[str, Any]) -> E:
        d = src_dict.copy()
        _what_failed = d.pop("what_failed", UNSET)
        what_failed: Union[Unset, ModelingCmdId]
        if isinstance(_what_failed, Unset):
            what_failed = UNSET
        else:
            what_failed = ModelingCmdId(_what_failed)

        cancelled = cls(
            what_failed=what_failed,
        )

        cancelled.additional_properties = d
        return cancelled

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties


ModelingOutcome = Union[Success, Error, Cancelled]



from typing import Any, Dict, Optional, Union

import httpx

from ...client import Client
from ...models.api_call_with_price import ApiCallWithPrice
from ...models.error import Error
from ...types import Response


def _get_kwargs(
    id: str,
    *,
    client: Client,
) -> Dict[str, Any]:
    url = "{}/api-calls/{id}".format(client.base_url, id=id)  # noqa: E501

    headers: Dict[str, Any] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    return {
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
    }


def _parse_response(
    *, response: httpx.Response
) -> Optional[Union[ApiCallWithPrice, Error]]:
    if response.status_code == 200:
        response_200 = ApiCallWithPrice.from_dict(response.json())
        return response_200
    if response.status_code == 400:
        response_4XX = Error.from_dict(response.json())
        return response_4XX
    if response.status_code == 500:
        response_5XX = Error.from_dict(response.json())
        return response_5XX
    return Error.from_dict(response.json())


def _build_response(
    *, response: httpx.Response
) -> Response[Optional[Union[ApiCallWithPrice, Error]]]:
    return Response(
        status_code=response.status_code,
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(response=response),
    )


def sync_detailed(
    id: str,
    *,
    client: Client,
) -> Response[Optional[Union[ApiCallWithPrice, Error]]]:
    kwargs = _get_kwargs(
        id=id,
        client=client,
    )

    response = httpx.get(
        verify=client.verify_ssl,
        **kwargs,
    )

    return _build_response(response=response)


def sync(
    id: str,
    *,
    client: Client,
) -> Optional[Union[ApiCallWithPrice, Error]]:
    """This endpoint requires authentication by any KittyCAD user. It returns details of the requested API call for the user.
    If the user is not authenticated to view the specified API call, then it is not returned.
    Only KittyCAD employees can view API calls for other users."""  # noqa: E501

    return sync_detailed(
        id=id,
        client=client,
    ).parsed


async def asyncio_detailed(
    id: str,
    *,
    client: Client,
) -> Response[Optional[Union[ApiCallWithPrice, Error]]]:
    kwargs = _get_kwargs(
        id=id,
        client=client,
    )

    async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
        response = await _client.get(**kwargs)

    return _build_response(response=response)


async def asyncio(
    id: str,
    *,
    client: Client,
) -> Optional[Union[ApiCallWithPrice, Error]]:
    """This endpoint requires authentication by any KittyCAD user. It returns details of the requested API call for the user.
    If the user is not authenticated to view the specified API call, then it is not returned.
    Only KittyCAD employees can view API calls for other users."""  # noqa: E501

    return (
        await asyncio_detailed(
            id=id,
            client=client,
        )
    ).parsed



from enum import Enum


class UnitVolume(str, Enum):
    """The valid types of volume units."""  # noqa: E501

    """# Cubic centimeters (cc or cm³) <https://en.wikipedia.org/wiki/Cubic_centimetre> """  # noqa: E501
    CUBIC_CENTIMETRES = "cubic_centimetres"
    """# Cubic feet (ft³) <https://en.wikipedia.org/wiki/Cubic_foot> """  # noqa: E501
    CUBIC_FEET = "cubic_feet"
    """# Cubic inches (cu in or in³) <https://en.wikipedia.org/wiki/Cubic_inch> """  # noqa: E501
    CUBIC_INCHES = "cubic_inches"
    """# Cubic metres (m³) <https://en.wikipedia.org/wiki/Cubic_metre> """  # noqa: E501
    CUBIC_METRES = "cubic_metres"
    """# Cubic yards (yd³) <https://en.wikipedia.org/wiki/Cubic_yard> """  # noqa: E501
    CUBIC_YARDS = "cubic_yards"
    """# Cups <https://en.wikipedia.org/wiki/Cup_(unit)> """  # noqa: E501
    CUPS = "cups"
    """# Drams <https://en.wikipedia.org/wiki/Fluid_dram> """  # noqa: E501
    DRAMS = "drams"
    """# Drops <https://en.wikipedia.org/wiki/Minim_(unit)> """  # noqa: E501
    DROPS = "drops"
    """# US Fluid Ounces (fl oz) <https://en.wikipedia.org/wiki/Fluid_ounce> """  # noqa: E501
    FLUID_OUNCES = "fluid_ounces"
    """# UK Fluid Ounces (fl oz) <https://en.wikipedia.org/wiki/Fluid_ounce> """  # noqa: E501
    FLUID_OUNCES_UK = "fluid_ounces_uk"
    """# US Gallons (gal US) <https://en.wikipedia.org/wiki/Gallon> """  # noqa: E501
    GALLONS = "gallons"
    """# UK/Imperial Gallons (gal) <https://en.wikipedia.org/wiki/Gallon> """  # noqa: E501
    GALLONS_UK = "gallons_uk"
    """# Liters (l) <https://en.wikipedia.org/wiki/Litre> """  # noqa: E501
    LITRES = "litres"
    """# Milliliters (ml) <https://en.wikipedia.org/wiki/Litre> """  # noqa: E501
    MILLILITRES = "millilitres"
    """# Pints <https://en.wikipedia.org/wiki/Pint> """  # noqa: E501
    PINTS = "pints"
    """# Pints in the United Kingdom (UK) <https://en.wikipedia.org/wiki/Pint> """  # noqa: E501
    PINTS_UK = "pints_uk"
    """# Quarts <https://en.wikipedia.org/wiki/Quart> """  # noqa: E501
    QUARTS = "quarts"
    """# Tablespoons (tbsp) <https://en.wikipedia.org/wiki/Tablespoon> """  # noqa: E501
    TABLESPOONS = "tablespoons"
    """# Teaspoons (tsp) <https://en.wikipedia.org/wiki/Teaspoon> """  # noqa: E501
    TEASPOONS = "teaspoons"

    def __str__(self) -> str:
        return str(self.value)



from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

L = TypeVar("L", bound="OAuth2ClientInfo")


@attr.s(auto_attribs=True)
class OAuth2ClientInfo:
    """Information about an OAuth 2.0 client."""  # noqa: E501

    csrf_token: Union[Unset, str] = UNSET
    pkce_code_verifier: Union[Unset, str] = UNSET
    url: Union[Unset, str] = UNSET

    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        csrf_token = self.csrf_token
        pkce_code_verifier = self.pkce_code_verifier
        url = self.url

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if csrf_token is not UNSET:
            field_dict["csrf_token"] = csrf_token
        if pkce_code_verifier is not UNSET:
            field_dict["pkce_code_verifier"] = pkce_code_verifier
        if url is not UNSET:
            field_dict["url"] = url

        return field_dict

    @classmethod
    def from_dict(cls: Type[L], src_dict: Dict[str, Any]) -> L:
        d = src_dict.copy()
        csrf_token = d.pop("csrf_token", UNSET)

        pkce_code_verifier = d.pop("pkce_code_verifier", UNSET)

        url = d.pop("url", UNSET)

        o_auth2_client_info = cls(
            csrf_token=csrf_token,
            pkce_code_verifier=pkce_code_verifier,
            url=url,
        )

        o_auth2_client_info.additional_properties = d
        return o_auth2_client_info

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from enum import Enum


class AsyncApiCallType(str, Enum):
    """The type of async API call."""  # noqa: E501

    """# File conversion. """  # noqa: E501
    FILE_CONVERSION = "FileConversion"
    """# File volume. """  # noqa: E501
    FILE_VOLUME = "FileVolume"
    """# File center of mass. """  # noqa: E501
    FILE_CENTER_OF_MASS = "FileCenterOfMass"
    """# File mass. """  # noqa: E501
    FILE_MASS = "FileMass"
    """# File density. """  # noqa: E501
    FILE_DENSITY = "FileDensity"
    """# File surface area. """  # noqa: E501
    FILE_SURFACE_AREA = "FileSurfaceArea"

    def __str__(self) -> str:
        return str(self.value)



from enum import Enum


class ApiCallQueryGroupBy(str, Enum):
    """The field of an API call to group by."""  # noqa: E501

    """# The email of the user that requested the API call. """  # noqa: E501
    EMAIL = "email"
    """# The HTTP method of the API call. """  # noqa: E501
    METHOD = "method"
    """# The endpoint of the API call. """  # noqa: E501
    ENDPOINT = "endpoint"
    """# The user ID of the user that requested the API call. """  # noqa: E501
    USER_ID = "user_id"
    """# The origin of the API call. This is parsed from the `Origin` header. """  # noqa: E501
    ORIGIN = "origin"
    """# The IP address of the user making the API call. """  # noqa: E501
    IP_ADDRESS = "ip_address"

    def __str__(self) -> str:
        return str(self.value)



from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..models.country_code import CountryCode
from ..types import UNSET, Unset

S = TypeVar("S", bound="NewAddress")


@attr.s(auto_attribs=True)
class NewAddress:
    """The struct that is used to create a new record. This is automatically generated and has all the same fields as the main struct only it is missing the `id`."""  # noqa: E501

    city: Union[Unset, str] = UNSET
    country: Union[Unset, CountryCode] = UNSET
    state: Union[Unset, str] = UNSET
    street1: Union[Unset, str] = UNSET
    street2: Union[Unset, str] = UNSET
    user_id: Union[Unset, str] = UNSET
    zip: Union[Unset, str] = UNSET

    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        city = self.city
        if not isinstance(self.country, Unset):
            country = self.country
        state = self.state
        street1 = self.street1
        street2 = self.street2
        user_id = self.user_id
        zip = self.zip

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if city is not UNSET:
            field_dict["city"] = city
        if country is not UNSET:
            field_dict["country"] = country
        if state is not UNSET:
            field_dict["state"] = state
        if street1 is not UNSET:
            field_dict["street1"] = street1
        if street2 is not UNSET:
            field_dict["street2"] = street2
        if user_id is not UNSET:
            field_dict["user_id"] = user_id
        if zip is not UNSET:
            field_dict["zip"] = zip

        return field_dict

    @classmethod
    def from_dict(cls: Type[S], src_dict: Dict[str, Any]) -> S:
        d = src_dict.copy()
        city = d.pop("city", UNSET)

        _country = d.pop("country", UNSET)
        country: Union[Unset, CountryCode]
        if isinstance(_country, Unset):
            country = UNSET
        else:
            country = _country  # type: ignore[arg-type]

        state = d.pop("state", UNSET)

        street1 = d.pop("street1", UNSET)

        street2 = d.pop("street2", UNSET)

        user_id = d.pop("user_id", UNSET)

        zip = d.pop("zip", UNSET)

        new_address = cls(
            city=city,
            country=country,
            state=state,
            street1=street1,
            street2=street2,
            user_id=user_id,
            zip=zip,
        )

        new_address.additional_properties = d
        return new_address

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

C = TypeVar("C", bound="ModelingError")


@attr.s(auto_attribs=True)
class ModelingError:
    """Why a command submitted to the Modeling API failed."""  # noqa: E501

    error_code: Union[Unset, str] = UNSET
    external_message: Union[Unset, str] = UNSET
    internal_message: Union[Unset, str] = UNSET
    status_code: Union[Unset, int] = UNSET

    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        error_code = self.error_code
        external_message = self.external_message
        internal_message = self.internal_message
        status_code = self.status_code

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if error_code is not UNSET:
            field_dict["error_code"] = error_code
        if external_message is not UNSET:
            field_dict["external_message"] = external_message
        if internal_message is not UNSET:
            field_dict["internal_message"] = internal_message
        if status_code is not UNSET:
            field_dict["status_code"] = status_code

        return field_dict

    @classmethod
    def from_dict(cls: Type[C], src_dict: Dict[str, Any]) -> C:
        d = src_dict.copy()
        error_code = d.pop("error_code", UNSET)

        external_message = d.pop("external_message", UNSET)

        internal_message = d.pop("internal_message", UNSET)

        status_code = d.pop("status_code", UNSET)

        modeling_error = cls(
            error_code=error_code,
            external_message=external_message,
            internal_message=internal_message,
            status_code=status_code,
        )

        modeling_error.additional_properties = d
        return modeling_error

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..models.ai_plugin_api import AiPluginApi
from ..models.ai_plugin_auth import AiPluginAuth
from ..types import UNSET, Unset

N = TypeVar("N", bound="AiPluginManifest")


@attr.s(auto_attribs=True)
class AiPluginManifest:
    """AI plugin manifest.

    This is used for OpenAI's ChatGPT plugins. You can read more about them [here](https://platform.openai.com/docs/plugins/getting-started/plugin-manifest)."""  # noqa: E501

    api: Union[Unset, AiPluginApi] = UNSET
    auth: Union[Unset, AiPluginAuth] = UNSET
    contact_email: Union[Unset, str] = UNSET
    description_for_human: Union[Unset, str] = UNSET
    description_for_model: Union[Unset, str] = UNSET
    legal_info_url: Union[Unset, str] = UNSET
    logo_url: Union[Unset, str] = UNSET
    name_for_human: Union[Unset, str] = UNSET
    name_for_model: Union[Unset, str] = UNSET
    schema_version: Union[Unset, str] = UNSET

    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        if not isinstance(self.api, Unset):
            api = self.api
        if not isinstance(self.auth, Unset):
            auth = self.auth
        contact_email = self.contact_email
        description_for_human = self.description_for_human
        description_for_model = self.description_for_model
        legal_info_url = self.legal_info_url
        logo_url = self.logo_url
        name_for_human = self.name_for_human
        name_for_model = self.name_for_model
        schema_version = self.schema_version

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if api is not UNSET:
            field_dict["api"] = api
        if auth is not UNSET:
            field_dict["auth"] = auth
        if contact_email is not UNSET:
            field_dict["contact_email"] = contact_email
        if description_for_human is not UNSET:
            field_dict["description_for_human"] = description_for_human
        if description_for_model is not UNSET:
            field_dict["description_for_model"] = description_for_model
        if legal_info_url is not UNSET:
            field_dict["legal_info_url"] = legal_info_url
        if logo_url is not UNSET:
            field_dict["logo_url"] = logo_url
        if name_for_human is not UNSET:
            field_dict["name_for_human"] = name_for_human
        if name_for_model is not UNSET:
            field_dict["name_for_model"] = name_for_model
        if schema_version is not UNSET:
            field_dict["schema_version"] = schema_version

        return field_dict

    @classmethod
    def from_dict(cls: Type[N], src_dict: Dict[str, Any]) -> N:
        d = src_dict.copy()
        _api = d.pop("api", UNSET)
        api: Union[Unset, AiPluginApi]
        if isinstance(_api, Unset):
            api = UNSET
        else:
            api = AiPluginApi(_api)

        _auth = d.pop("auth", UNSET)
        auth: Union[Unset, AiPluginAuth]
        if isinstance(_auth, Unset):
            auth = UNSET
        else:
            auth = AiPluginAuth(_auth)

        contact_email = d.pop("contact_email", UNSET)

        description_for_human = d.pop("description_for_human", UNSET)

        description_for_model = d.pop("description_for_model", UNSET)

        legal_info_url = d.pop("legal_info_url", UNSET)

        logo_url = d.pop("logo_url", UNSET)

        name_for_human = d.pop("name_for_human", UNSET)

        name_for_model = d.pop("name_for_model", UNSET)

        schema_version = d.pop("schema_version", UNSET)

        ai_plugin_manifest = cls(
            api=api,
            auth=auth,
            contact_email=contact_email,
            description_for_human=description_for_human,
            description_for_model=description_for_model,
            legal_info_url=legal_info_url,
            logo_url=logo_url,
            name_for_human=name_for_human,
            name_for_model=name_for_model,
            schema_version=schema_version,
        )

        ai_plugin_manifest.additional_properties = d
        return ai_plugin_manifest

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

M = TypeVar("M", bound="ModelingOutcomes")


@attr.s(auto_attribs=True)
class ModelingOutcomes:
    """The result from a batch of modeling commands."""  # noqa: E501

    outcomes: Union[Unset, Any] = UNSET

    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        outcomes = self.outcomes

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if outcomes is not UNSET:
            field_dict["outcomes"] = outcomes

        return field_dict

    @classmethod
    def from_dict(cls: Type[M], src_dict: Dict[str, Any]) -> M:
        d = src_dict.copy()
        outcomes = d.pop("outcomes", UNSET)

        modeling_outcomes = cls(
            outcomes=outcomes,
        )

        modeling_outcomes.additional_properties = d
        return modeling_outcomes

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

K = TypeVar("K", bound="JetstreamConfig")


@attr.s(auto_attribs=True)
class JetstreamConfig:
    """Jetstream configuration."""  # noqa: E501

    domain: Union[Unset, str] = UNSET
    max_memory: Union[Unset, int] = UNSET
    max_storage: Union[Unset, int] = UNSET
    store_dir: Union[Unset, str] = UNSET

    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        domain = self.domain
        max_memory = self.max_memory
        max_storage = self.max_storage
        store_dir = self.store_dir

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if domain is not UNSET:
            field_dict["domain"] = domain
        if max_memory is not UNSET:
            field_dict["max_memory"] = max_memory
        if max_storage is not UNSET:
            field_dict["max_storage"] = max_storage
        if store_dir is not UNSET:
            field_dict["store_dir"] = store_dir

        return field_dict

    @classmethod
    def from_dict(cls: Type[K], src_dict: Dict[str, Any]) -> K:
        d = src_dict.copy()
        domain = d.pop("domain", UNSET)

        max_memory = d.pop("max_memory", UNSET)

        max_storage = d.pop("max_storage", UNSET)

        store_dir = d.pop("store_dir", UNSET)

        jetstream_config = cls(
            domain=domain,
            max_memory=max_memory,
            max_storage=max_storage,
            store_dir=store_dir,
        )

        jetstream_config.additional_properties = d
        return jetstream_config

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any, Dict, Optional

import httpx

from ...client import Client
from ...models.error import Error
from ...types import Response


def _get_kwargs(
    token: str,
    *,
    client: Client,
) -> Dict[str, Any]:
    url = "{}/user/api-tokens/{token}".format(
        client.base_url, token=token
    )  # noqa: E501

    headers: Dict[str, Any] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    return {
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
    }


def _parse_response(*, response: httpx.Response) -> Optional[Error]:
    return None
    if response.status_code == 400:
        response_4XX = Error.from_dict(response.json())
        return response_4XX
    if response.status_code == 500:
        response_5XX = Error.from_dict(response.json())
        return response_5XX
    return Error.from_dict(response.json())


def _build_response(*, response: httpx.Response) -> Response[Optional[Error]]:
    return Response(
        status_code=response.status_code,
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(response=response),
    )


def sync_detailed(
    token: str,
    *,
    client: Client,
) -> Response[Optional[Error]]:
    kwargs = _get_kwargs(
        token=token,
        client=client,
    )

    response = httpx.delete(
        verify=client.verify_ssl,
        **kwargs,
    )

    return _build_response(response=response)


def sync(
    token: str,
    *,
    client: Client,
) -> Optional[Error]:
    """This endpoint requires authentication by any KittyCAD user. It deletes the requested API token for the user.
    This endpoint does not actually delete the API token from the database. It merely marks the token as invalid. We still want to keep the token in the database for historical purposes."""  # noqa: E501

    return sync_detailed(
        token=token,
        client=client,
    ).parsed


async def asyncio_detailed(
    token: str,
    *,
    client: Client,
) -> Response[Optional[Error]]:
    kwargs = _get_kwargs(
        token=token,
        client=client,
    )

    async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
        response = await _client.delete(**kwargs)

    return _build_response(response=response)


async def asyncio(
    token: str,
    *,
    client: Client,
) -> Optional[Error]:
    """This endpoint requires authentication by any KittyCAD user. It deletes the requested API token for the user.
    This endpoint does not actually delete the API token from the database. It merely marks the token as invalid. We still want to keep the token in the database for historical purposes."""  # noqa: E501

    return (
        await asyncio_detailed(
            token=token,
            client=client,
        )
    ).parsed



from enum import Enum


class CountryCode(str, Enum):
    """An enumeration of all ISO-3166 alpha-2 country codes."""  # noqa: E501

    """# Afghanistan """  # noqa: E501
    AF = "AF"
    """# Åland Islands """  # noqa: E501
    AX = "AX"
    """# Albania """  # noqa: E501
    AL = "AL"
    """# Algeria """  # noqa: E501
    DZ = "DZ"
    """# American Samoa """  # noqa: E501
    AS = "AS"
    """# Andorra """  # noqa: E501
    AD = "AD"
    """# Angola """  # noqa: E501
    AO = "AO"
    """# Anguilla """  # noqa: E501
    AI = "AI"
    """# Antarctica """  # noqa: E501
    AQ = "AQ"
    """# Antigua and Barbuda """  # noqa: E501
    AG = "AG"
    """# Argentina """  # noqa: E501
    AR = "AR"
    """# Armenia """  # noqa: E501
    AM = "AM"
    """# Aruba """  # noqa: E501
    AW = "AW"
    """# Australia """  # noqa: E501
    AU = "AU"
    """# Austria """  # noqa: E501
    AT = "AT"
    """# Azerbaijan """  # noqa: E501
    AZ = "AZ"
    """# Bahamas """  # noqa: E501
    BS = "BS"
    """# Bahrain """  # noqa: E501
    BH = "BH"
    """# Bangladesh """  # noqa: E501
    BD = "BD"
    """# Barbados """  # noqa: E501
    BB = "BB"
    """# Belarus """  # noqa: E501
    BY = "BY"
    """# Belgium """  # noqa: E501
    BE = "BE"
    """# Belize """  # noqa: E501
    BZ = "BZ"
    """# Benin """  # noqa: E501
    BJ = "BJ"
    """# Bermuda """  # noqa: E501
    BM = "BM"
    """# Bhutan """  # noqa: E501
    BT = "BT"
    """# Bolivia (Plurinational State of) """  # noqa: E501
    BO = "BO"
    """# Bonaire, Sint Eustatius and Saba """  # noqa: E501
    BQ = "BQ"
    """# Bosnia and Herzegovina """  # noqa: E501
    BA = "BA"
    """# Botswana """  # noqa: E501
    BW = "BW"
    """# Bouvet Island """  # noqa: E501
    BV = "BV"
    """# Brazil """  # noqa: E501
    BR = "BR"
    """# British Indian Ocean Territory """  # noqa: E501
    IO = "IO"
    """# Brunei Darussalam """  # noqa: E501
    BN = "BN"
    """# Bulgaria """  # noqa: E501
    BG = "BG"
    """# Burkina Faso """  # noqa: E501
    BF = "BF"
    """# Burundi """  # noqa: E501
    BI = "BI"
    """# Cabo Verde """  # noqa: E501
    CV = "CV"
    """# Cambodia """  # noqa: E501
    KH = "KH"
    """# Cameroon """  # noqa: E501
    CM = "CM"
    """# Canada """  # noqa: E501
    CA = "CA"
    """# Cayman Islands """  # noqa: E501
    KY = "KY"
    """# Central African Republic """  # noqa: E501
    CF = "CF"
    """# Chad """  # noqa: E501
    TD = "TD"
    """# Chile """  # noqa: E501
    CL = "CL"
    """# China """  # noqa: E501
    CN = "CN"
    """# Christmas Island """  # noqa: E501
    CX = "CX"
    """# Cocos (Keeling) Islands """  # noqa: E501
    CC = "CC"
    """# Colombia """  # noqa: E501
    CO = "CO"
    """# Comoros """  # noqa: E501
    KM = "KM"
    """# Congo """  # noqa: E501
    CG = "CG"
    """# Congo (Democratic Republic of the) """  # noqa: E501
    CD = "CD"
    """# Cook Islands """  # noqa: E501
    CK = "CK"
    """# Costa Rica """  # noqa: E501
    CR = "CR"
    """# Côte d'Ivoire """  # noqa: E501
    CI = "CI"
    """# Croatia """  # noqa: E501
    HR = "HR"
    """# Cuba """  # noqa: E501
    CU = "CU"
    """# Curaçao """  # noqa: E501
    CW = "CW"
    """# Cyprus """  # noqa: E501
    CY = "CY"
    """# Czechia """  # noqa: E501
    CZ = "CZ"
    """# Denmark """  # noqa: E501
    DK = "DK"
    """# Djibouti """  # noqa: E501
    DJ = "DJ"
    """# Dominica """  # noqa: E501
    DM = "DM"
    """# Dominican Republic """  # noqa: E501
    DO = "DO"
    """# Ecuador """  # noqa: E501
    EC = "EC"
    """# Egypt """  # noqa: E501
    EG = "EG"
    """# El Salvador """  # noqa: E501
    SV = "SV"
    """# Equatorial Guinea """  # noqa: E501
    GQ = "GQ"
    """# Eritrea """  # noqa: E501
    ER = "ER"
    """# Estonia """  # noqa: E501
    EE = "EE"
    """# Ethiopia """  # noqa: E501
    ET = "ET"
    """# Falkland Islands (Malvinas) """  # noqa: E501
    FK = "FK"
    """# Faroe Islands """  # noqa: E501
    FO = "FO"
    """# Fiji """  # noqa: E501
    FJ = "FJ"
    """# Finland """  # noqa: E501
    FI = "FI"
    """# France """  # noqa: E501
    FR = "FR"
    """# French Guiana """  # noqa: E501
    GF = "GF"
    """# French Polynesia """  # noqa: E501
    PF = "PF"
    """# French Southern Territories """  # noqa: E501
    TF = "TF"
    """# Gabon """  # noqa: E501
    GA = "GA"
    """# Gambia """  # noqa: E501
    GM = "GM"
    """# Georgia """  # noqa: E501
    GE = "GE"
    """# Germany """  # noqa: E501
    DE = "DE"
    """# Ghana """  # noqa: E501
    GH = "GH"
    """# Gibraltar """  # noqa: E501
    GI = "GI"
    """# Greece """  # noqa: E501
    GR = "GR"
    """# Greenland """  # noqa: E501
    GL = "GL"
    """# Grenada """  # noqa: E501
    GD = "GD"
    """# Guadeloupe """  # noqa: E501
    GP = "GP"
    """# Guam """  # noqa: E501
    GU = "GU"
    """# Guatemala """  # noqa: E501
    GT = "GT"
    """# Guernsey """  # noqa: E501
    GG = "GG"
    """# Guinea """  # noqa: E501
    GN = "GN"
    """# Guinea-Bissau """  # noqa: E501
    GW = "GW"
    """# Guyana """  # noqa: E501
    GY = "GY"
    """# Haiti """  # noqa: E501
    HT = "HT"
    """# Heard Island and McDonald Islands """  # noqa: E501
    HM = "HM"
    """# Holy See """  # noqa: E501
    VA = "VA"
    """# Honduras """  # noqa: E501
    HN = "HN"
    """# Hong Kong """  # noqa: E501
    HK = "HK"
    """# Hungary """  # noqa: E501
    HU = "HU"
    """# Iceland """  # noqa: E501
    IS = "IS"
    """# India """  # noqa: E501
    IN = "IN"
    """# Indonesia """  # noqa: E501
    ID = "ID"
    """# Iran (Islamic Republic of) """  # noqa: E501
    IR = "IR"
    """# Iraq """  # noqa: E501
    IQ = "IQ"
    """# Ireland """  # noqa: E501
    IE = "IE"
    """# Isle of Man """  # noqa: E501
    IM = "IM"
    """# Israel """  # noqa: E501
    IL = "IL"
    """# Italy """  # noqa: E501
    IT = "IT"
    """# Jamaica """  # noqa: E501
    JM = "JM"
    """# Japan """  # noqa: E501
    JP = "JP"
    """# Jersey """  # noqa: E501
    JE = "JE"
    """# Jordan """  # noqa: E501
    JO = "JO"
    """# Kazakhstan """  # noqa: E501
    KZ = "KZ"
    """# Kenya """  # noqa: E501
    KE = "KE"
    """# Kiribati """  # noqa: E501
    KI = "KI"
    """# Korea (Democratic People's Republic of) """  # noqa: E501
    KP = "KP"
    """# Korea (Republic of) """  # noqa: E501
    KR = "KR"
    """# Kuwait """  # noqa: E501
    KW = "KW"
    """# Kyrgyzstan """  # noqa: E501
    KG = "KG"
    """# Lao People's Democratic Republic """  # noqa: E501
    LA = "LA"
    """# Latvia """  # noqa: E501
    LV = "LV"
    """# Lebanon """  # noqa: E501
    LB = "LB"
    """# Lesotho """  # noqa: E501
    LS = "LS"
    """# Liberia """  # noqa: E501
    LR = "LR"
    """# Libya """  # noqa: E501
    LY = "LY"
    """# Liechtenstein """  # noqa: E501
    LI = "LI"
    """# Lithuania """  # noqa: E501
    LT = "LT"
    """# Luxembourg """  # noqa: E501
    LU = "LU"
    """# Macao """  # noqa: E501
    MO = "MO"
    """# Macedonia (the former Yugoslav Republic of) """  # noqa: E501
    MK = "MK"
    """# Madagascar """  # noqa: E501
    MG = "MG"
    """# Malawi """  # noqa: E501
    MW = "MW"
    """# Malaysia """  # noqa: E501
    MY = "MY"
    """# Maldives """  # noqa: E501
    MV = "MV"
    """# Mali """  # noqa: E501
    ML = "ML"
    """# Malta """  # noqa: E501
    MT = "MT"
    """# Marshall Islands """  # noqa: E501
    MH = "MH"
    """# Martinique """  # noqa: E501
    MQ = "MQ"
    """# Mauritania """  # noqa: E501
    MR = "MR"
    """# Mauritius """  # noqa: E501
    MU = "MU"
    """# Mayotte """  # noqa: E501
    YT = "YT"
    """# Mexico """  # noqa: E501
    MX = "MX"
    """# Micronesia (Federated States of) """  # noqa: E501
    FM = "FM"
    """# Moldova (Republic of) """  # noqa: E501
    MD = "MD"
    """# Monaco """  # noqa: E501
    MC = "MC"
    """# Mongolia """  # noqa: E501
    MN = "MN"
    """# Montenegro """  # noqa: E501
    ME = "ME"
    """# Montserrat """  # noqa: E501
    MS = "MS"
    """# Morocco """  # noqa: E501
    MA = "MA"
    """# Mozambique """  # noqa: E501
    MZ = "MZ"
    """# Myanmar """  # noqa: E501
    MM = "MM"
    """# Namibia """  # noqa: E501
    NA = "NA"
    """# Nauru """  # noqa: E501
    NR = "NR"
    """# Nepal """  # noqa: E501
    NP = "NP"
    """# Netherlands """  # noqa: E501
    NL = "NL"
    """# New Caledonia """  # noqa: E501
    NC = "NC"
    """# New Zealand """  # noqa: E501
    NZ = "NZ"
    """# Nicaragua """  # noqa: E501
    NI = "NI"
    """# Niger """  # noqa: E501
    NE = "NE"
    """# Nigeria """  # noqa: E501
    NG = "NG"
    """# Niue """  # noqa: E501
    NU = "NU"
    """# Norfolk Island """  # noqa: E501
    NF = "NF"
    """# Northern Mariana Islands """  # noqa: E501
    MP = "MP"
    """# Norway """  # noqa: E501
    NO = "NO"
    """# Oman """  # noqa: E501
    OM = "OM"
    """# Pakistan """  # noqa: E501
    PK = "PK"
    """# Palau """  # noqa: E501
    PW = "PW"
    """# Palestine, State of """  # noqa: E501
    PS = "PS"
    """# Panama """  # noqa: E501
    PA = "PA"
    """# Papua New Guinea """  # noqa: E501
    PG = "PG"
    """# Paraguay """  # noqa: E501
    PY = "PY"
    """# Peru """  # noqa: E501
    PE = "PE"
    """# Philippines """  # noqa: E501
    PH = "PH"
    """# Pitcairn """  # noqa: E501
    PN = "PN"
    """# Poland """  # noqa: E501
    PL = "PL"
    """# Portugal """  # noqa: E501
    PT = "PT"
    """# Puerto Rico """  # noqa: E501
    PR = "PR"
    """# Qatar """  # noqa: E501
    QA = "QA"
    """# Réunion """  # noqa: E501
    RE = "RE"
    """# Romania """  # noqa: E501
    RO = "RO"
    """# Russian Federation """  # noqa: E501
    RU = "RU"
    """# Rwanda """  # noqa: E501
    RW = "RW"
    """# Saint Barthélemy """  # noqa: E501
    BL = "BL"
    """# Saint Helena, Ascension and Tristan da Cunha """  # noqa: E501
    SH = "SH"
    """# Saint Kitts and Nevis """  # noqa: E501
    KN = "KN"
    """# Saint Lucia """  # noqa: E501
    LC = "LC"
    """# Saint Martin (French part) """  # noqa: E501
    MF = "MF"
    """# Saint Pierre and Miquelon """  # noqa: E501
    PM = "PM"
    """# Saint Vincent and the Grenadines """  # noqa: E501
    VC = "VC"
    """# Samoa """  # noqa: E501
    WS = "WS"
    """# San Marino """  # noqa: E501
    SM = "SM"
    """# Sao Tome and Principe """  # noqa: E501
    ST = "ST"
    """# Saudi Arabia """  # noqa: E501
    SA = "SA"
    """# Senegal """  # noqa: E501
    SN = "SN"
    """# Serbia """  # noqa: E501
    RS = "RS"
    """# Seychelles """  # noqa: E501
    SC = "SC"
    """# Sierra Leone """  # noqa: E501
    SL = "SL"
    """# Singapore """  # noqa: E501
    SG = "SG"
    """# Sint Maarten (Dutch part) """  # noqa: E501
    SX = "SX"
    """# Slovakia """  # noqa: E501
    SK = "SK"
    """# Slovenia """  # noqa: E501
    SI = "SI"
    """# Solomon Islands """  # noqa: E501
    SB = "SB"
    """# Somalia """  # noqa: E501
    SO = "SO"
    """# South Africa """  # noqa: E501
    ZA = "ZA"
    """# South Georgia and the South Sandwich Islands """  # noqa: E501
    GS = "GS"
    """# South Sudan """  # noqa: E501
    SS = "SS"
    """# Spain """  # noqa: E501
    ES = "ES"
    """# Sri Lanka """  # noqa: E501
    LK = "LK"
    """# Sudan """  # noqa: E501
    SD = "SD"
    """# Suriname """  # noqa: E501
    SR = "SR"
    """# Svalbard and Jan Mayen """  # noqa: E501
    SJ = "SJ"
    """# Swaziland """  # noqa: E501
    SZ = "SZ"
    """# Sweden """  # noqa: E501
    SE = "SE"
    """# Switzerland """  # noqa: E501
    CH = "CH"
    """# Syrian Arab Republic """  # noqa: E501
    SY = "SY"
    """# Taiwan, Province of China """  # noqa: E501
    TW = "TW"
    """# Tajikistan """  # noqa: E501
    TJ = "TJ"
    """# Tanzania, United Republic of """  # noqa: E501
    TZ = "TZ"
    """# Thailand """  # noqa: E501
    TH = "TH"
    """# Timor-Leste """  # noqa: E501
    TL = "TL"
    """# Togo """  # noqa: E501
    TG = "TG"
    """# Tokelau """  # noqa: E501
    TK = "TK"
    """# Tonga """  # noqa: E501
    TO = "TO"
    """# Trinidad and Tobago """  # noqa: E501
    TT = "TT"
    """# Tunisia """  # noqa: E501
    TN = "TN"
    """# Turkey """  # noqa: E501
    TR = "TR"
    """# Turkmenistan """  # noqa: E501
    TM = "TM"
    """# Turks and Caicos Islands """  # noqa: E501
    TC = "TC"
    """# Tuvalu """  # noqa: E501
    TV = "TV"
    """# Uganda """  # noqa: E501
    UG = "UG"
    """# Ukraine """  # noqa: E501
    UA = "UA"
    """# United Arab Emirates """  # noqa: E501
    AE = "AE"
    """# United Kingdom of Great Britain and Northern Ireland """  # noqa: E501
    GB = "GB"
    """# United States of America """  # noqa: E501
    US = "US"
    """# United States Minor Outlying Islands """  # noqa: E501
    UM = "UM"
    """# Uruguay """  # noqa: E501
    UY = "UY"
    """# Uzbekistan """  # noqa: E501
    UZ = "UZ"
    """# Vanuatu """  # noqa: E501
    VU = "VU"
    """# Venezuela (Bolivarian Republic of) """  # noqa: E501
    VE = "VE"
    """# Viet Nam """  # noqa: E501
    VN = "VN"
    """# Virgin Islands (British) """  # noqa: E501
    VG = "VG"
    """# Virgin Islands (U.S.) """  # noqa: E501
    VI = "VI"
    """# Wallis and Futuna """  # noqa: E501
    WF = "WF"
    """# Western Sahara """  # noqa: E501
    EH = "EH"
    """# Yemen """  # noqa: E501
    YE = "YE"
    """# Zambia """  # noqa: E501
    ZM = "ZM"
    """# Zimbabwe """  # noqa: E501
    ZW = "ZW"

    def __str__(self) -> str:
        return str(self.value)



from enum import Enum


class InvoiceStatus(str, Enum):
    """An enum representing the possible values of an `Invoice`'s `status` field."""  # noqa: E501

    """# Deleted. """  # noqa: E501
    DELETED = "deleted"
    """# Draft. """  # noqa: E501
    DRAFT = "draft"
    """# Open. """  # noqa: E501
    OPEN = "open"
    """# Paid. """  # noqa: E501
    PAID = "paid"
    """# Uncollectible. """  # noqa: E501
    UNCOLLECTIBLE = "uncollectible"
    """# Void. """  # noqa: E501
    VOID = "void"

    def __str__(self) -> str:
        return str(self.value)



from enum import Enum


class FileExportFormat(str, Enum):
    """The valid types of output file formats."""  # noqa: E501

    """# The COLLADA/DAE file format. <https://en.wikipedia.org/wiki/COLLADA> """  # noqa: E501
    DAE = "dae"
    """# The DXF file format. <https://en.wikipedia.org/wiki/AutoCAD_DXF> """  # noqa: E501
    DXF = "dxf"
    """# The FBX file format. <https://en.wikipedia.org/wiki/FBX> """  # noqa: E501
    FBX = "fbx"
    """# The FBX file format (in binary). <https://en.wikipedia.org/wiki/FBX> """  # noqa: E501
    FBXB = "fbxb"
    """# glTF 2.0. We refer to this as glTF since that is how our customers refer to it, although by default it will be in binary format and thus technically (glb). """  # noqa: E501
    GLTF = "gltf"
    """# The OBJ file format. <https://en.wikipedia.org/wiki/Wavefront_.obj_file> It may or may not have an an attached material (mtl // mtllib) within the file, but we interact with it as if it does not. """  # noqa: E501
    OBJ = "obj"
    """# The PLY file format. <https://en.wikipedia.org/wiki/PLY_(file_format)> """  # noqa: E501
    PLY = "ply"
    """# The STEP file format. <https://en.wikipedia.org/wiki/ISO_10303-21> """  # noqa: E501
    STEP = "step"
    """# The STL file format. <https://en.wikipedia.org/wiki/STL_(file_format)> """  # noqa: E501
    STL = "stl"

    def __str__(self) -> str:
        return str(self.value)
